/***************************************************************************
 *                                                                         *
 *   cad/cadarc.cpp                                                        *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "cadarc.h"

#include <cmath>

using namespace cad;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CADArc::CADArc(QString layer, double centerX, double centerY,	double radius, 
	double startAngle, double endAngle)
{
	this->layer = layer;
	this->centerX = centerX;
	this->centerY = centerY;
	this->radius = radius;
	this->startAngle = startAngle;
	this->endAngle = endAngle;
}

CADArc::~CADArc()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

double CADArc::getCenterX() const
{
	return centerX;
}

double CADArc::getCenterY() const
{
	return centerY;
}

double CADArc::getRadius() const
{
	return radius;
}

double CADArc::getStartAngle() const
{
	return startAngle;
}

double CADArc::getEndAngle() const
{
	return endAngle;
}

double CADArc::getAngle() const
{
	return endAngle - startAngle;
}

double CADArc::getLength() const
{
	double angle = endAngle - startAngle;
	return (radius * (4*atan(1.0)) * angle) / 180;
}

void CADArc::setCenterX(double x)
{
	centerX = x;
}

void CADArc::setCenterY(double y)
{
	centerY = y;
}

void CADArc::setCenter(double x, double y)
{
	centerX = x;
	centerY = y;
}

void CADArc::setRadius(double radius)
{
	this->radius = radius;
}

void CADArc::setStartAngle(double startAngle)
{
	this->startAngle = startAngle;
}

void CADArc::setEndAngle(double endAngle)
{
	this->endAngle = endAngle;
}

// EOF
