/***************************************************************************
 *                                                                         *
 *   cad/cadcoordinate.cpp                                                 *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "cadcoordinate.h"

#include <qobject.h>
#include <math.h>

using cad::CADCoordinate;
using util::Exception;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CADCoordinate::CADCoordinate(double x, double y, bool absolute)
{
	this->x = x;
	this->y = y;
}

CADCoordinate::~CADCoordinate()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/
		
double CADCoordinate::getX() const
{
	return x;
}

double CADCoordinate::getY() const
{
	return y;
}

double CADCoordinate::getDistance() const
{
	return sqrt(pow(x, 2) + pow(y, 2));
}

double CADCoordinate::getAngle() const
{
	if (x == 0.0)
		return 0.0;
	return atan((y/x) * (180/(4*atan(1))));
}

void CADCoordinate::set(double x, double y)
{
	this->x = x;
	this->y = y;
}

void CADCoordinate::set(QString s) throw (Exception)
{
	bool absolute = true;
	if (s[0] == '@')
	{
		absolute = false;
		s = s.mid(1);
	}
	
	int position;
	if ((position = s.find(',')) != -1)
	{
		bool ok = false;
		QString number = s.left(position);
		double x = number.toDouble(&ok);
		if (!ok)
			throw Exception(QObject::tr("No valid coordinate"));
		number = s.mid(position + 1);
		double y = number.toDouble(&ok);
		if (!ok)
			throw Exception(QObject::tr("No valid coordinate"));
		setX(x);
		setY(y);
	}
	else if ((position = s.find('<')) != -1)
	{
		bool ok = false;
		QString number = s.left(position);
		double distance = number.toDouble(&ok);
		if (!ok)
			throw Exception(QObject::tr("No valid coordinate"));
		number = s.mid(position + 1);
		double angle = number.toDouble(&ok);
		if (!ok)
			throw Exception(QObject::tr("No valid coordinate"));
		setDistance(distance);
		setAngle(angle);
	}
	else
		throw Exception(QObject::tr("No valid coordinate"));
	
	setAbsolute(absolute);
}

void CADCoordinate::setX(double x)
{
	this->x = x;
}

void CADCoordinate::setY(double y)
{
	this->y = y;
}

void CADCoordinate::setDistance(double distance)
{
	double angle = getAngle();
	x = distance * cos(angle / (180/(4*atan(1))));
	y = distance * sin(angle / (180/(4*atan(1))));
}

void CADCoordinate::setAngle(double angle)
{
	double distance = getDistance();
	x = distance * cos(angle / (180/(4*atan(1))));
	y = distance * sin(angle / (180/(4*atan(1))));
}
		
bool CADCoordinate::getAbsolute() const
{
	return absolute;
}

void CADCoordinate::setAbsolute(bool absolute)
{
	this->absolute = absolute;
}

/***************************************************************************
 * Operators                                                               *
 ***************************************************************************/

CADCoordinate CADCoordinate::operator+(CADCoordinate c)
{
	double x = this->x + c.x;
	double y = this->y + c.y;
	return CADCoordinate(x, y);
}

// EOF
