/***************************************************************************
 *                                                                         *
 *   cad/caddrawing.h                                                      *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__CADDRAWING_H
#define CAD__CADDRAWING_H

#include "cadentitycontainer.h"
#include "../util/layerrenamingmanager.h"

namespace cad
{
	using util::LayerRenamingManager;

	/**
	 * CADDrawing contains all information about a complete 
	 * drawing and can be saved to a file.
	 * @author Christoph Permes
	 */
	class CADDrawing : public CADEntityContainer
	{
	public:
		CADDrawing();
		virtual ~CADDrawing();
		
		/** @return the active pen */
		CADPen getActivePen() const
		{ return activePen; }
		/** @return the layer list */
		CADLayerList getLayerList() const
		{ return layerList; }
		/** @return the linetype list */
		CADLinetypeList getLinetypeList() const
		{ return linetypeList; }
		/** @return the active layer */
		CADLayer getActiveLayer() const;
		
		/** set the active pen */
		void setActivePen(CADPen pen)
		{ this->activePen = pen; }
		/** set the active layer */
		void setActiveLayer(QString name) throw (Exception);
		
		/** update the layer list */
		void updateLayerList(CADLayerList layerList, LayerRenamingManager rm);
		/** update the linetype list */
		void updateLinetypeList(CADLinetypeList linetypeList);
		
	private:
		//! active pen
		CADPen activePen;
		//! the layer list
		CADLayerList layerList;
		//! list of available linetypes
		CADLinetypeList linetypeList;
		
	};
}

#endif // CAD__CADDRAWING_H
