/***************************************************************************
 *                                                                         *
 *   cad/cadellipse.cpp                                                    *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "cadellipse.h"

#include <cmath>

using namespace cad;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CADEllipse::CADEllipse(QString layer, double centerX, double centerY, 
	double majorAxisVectorX, double majorAxisVectorY, double axisRatio, 
	double startAngle, double endAngle)
{
	this->centerX = centerX;
	this->centerY = centerY;
	this->majorAxisVectorX = majorAxisVectorX;
	this->majorAxisVectorY = majorAxisVectorY;
	this->axisRatio = axisRatio;
	setStartAngle(startAngle);
	setEndAngle(endAngle);
}

CADEllipse::~CADEllipse()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

double CADEllipse::getCenterX() const
{
	return centerX;
}

double CADEllipse::getCenterY() const
{
	return centerY;
}

double CADEllipse::getMajorAxis() const
{
	return sqrt(pow(majorAxisVectorX, 2) + pow(majorAxisVectorY, 2));
}

double CADEllipse::getMinorAxis() const
{
	return getMajorAxis() * axisRatio;
}

double CADEllipse::getAxisRatio() const
{
	return axisRatio;
}

double CADEllipse::getStartAngle() const
{
	return startAngle;
}

double CADEllipse::getEndAngle() const
{
	return endAngle;
}

double CADEllipse::getMajorAxisVectorX() const
{
	return majorAxisVectorX;
}

double CADEllipse::getMajorAxisVectorY() const
{
	return majorAxisVectorY;
}

double CADEllipse::getMinorAxisVectorX() const
{
	double alpha;
	if (majorAxisVectorX == 0.0)
		alpha = (4*atan(1.0))/4;
	if (majorAxisVectorY == 0.0)
		alpha = 0.0;
	else
		alpha = (4*atan(1.0))/2 + atan(majorAxisVectorY/majorAxisVectorX);
	return getMinorAxis() * cos(alpha);
}

double CADEllipse::getMinorAxisVectorY() const
{
	double alpha;
	if (majorAxisVectorX == 0.0)
		alpha = (4*atan(1.0))/4;
	if (majorAxisVectorY == 0.0)
		alpha = 0.0;
	else
		alpha = (4*atan(1.0))/2 + atan(majorAxisVectorY/majorAxisVectorX);
	qDebug("tan: "+QString::number(atan(majorAxisVectorY/majorAxisVectorX)));
	return getMinorAxis() * sin(alpha);
}

void CADEllipse::setCenter(double x, double y)
{
	centerX = x;
	centerY = y;
}

void CADEllipse::setCenterX(double x)
{
	centerX = x;
}

void CADEllipse::setCenterY(double y)
{
	centerY = y;
}

void CADEllipse::setMajorAxis(double majorAxis)
{
	double alpha;
	if (majorAxisVectorX == 0.0)
		alpha = 0.0;
	else
		alpha = atan(majorAxisVectorY/majorAxisVectorX);
	majorAxisVectorX = cos(alpha) * majorAxis;
}

void CADEllipse::setMinorAxis(double minorAxis)
{
	if (getMajorAxis() == 0.0)
		axisRatio = 0.0;
	else
		axisRatio = minorAxis/getMajorAxis();
}

void CADEllipse::setAxisRatio(double axisRatio)
{
	this->axisRatio = axisRatio;
}

void CADEllipse::setStartAngle(double startAngle)
{
	this->startAngle = fabs(startAngle);
	while (this->startAngle > 360.0)
		this->startAngle -= 360.0;
	if (startAngle < 0)
		this->startAngle = 360 - this->startAngle;
		
}

void CADEllipse::setEndAngle(double endAngle)
{
	this->endAngle = fabs(endAngle);
	while (this->endAngle > 360.0)
		this->endAngle -= 360.0;
	if (endAngle < 0)
		this->endAngle = 360 - this->endAngle;
}

void CADEllipse::setMajorAxisVectorX(double majorAxisVectorX)
{
	this->majorAxisVectorX = majorAxisVectorX;
}

void CADEllipse::setMajorAxisVectorY(double majorAxisVectorY)
{
	this->majorAxisVectorY = majorAxisVectorY;
}

// EOF
