/***************************************************************************
 *                                                                         *
 *   cad/cadellipse.h                                                      *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__CADELLIPSE_H
#define CAD__CADELLIPSE_H

#include "cadentity.h"

namespace cad
{

	/**
	 * CADEllipse represents a geometrical Ellipse
	 * @author Christoph Permes
	 */
	class CADEllipse : public CADEntity
	{
	public:
		CADEllipse(QString layer, double centerX = 0.0, 
			double centerY = 0.0, double majorAxisVectorX = 0.0, 
			double majorAxisVectorY = 0.0, double axisRatio = 0.0, 
			double startAngle = 0.0, double endAngle = 0.0);
		~CADEllipse();
	
		/** @return ID_CADELLIPSE as entity ID */
		virtual CADEntityType getEntityType() const
		{ return ID_CADELLIPSE; }
		
		double getCenterX() const;
		double getCenterY() const;
		double getMajorAxis() const;
		double getMinorAxis() const;
		double getAxisRatio() const;
		double getStartAngle() const;
		double getEndAngle() const;
		double getMajorAxisVectorX() const;
		double getMajorAxisVectorY() const;
		double getMinorAxisVectorX() const;
		double getMinorAxisVectorY() const;
	
		void setCenter(double x, double y);
		void setCenterX(double x);
		void setCenterY(double y);
		void setMajorAxis(double majorAxis);
		void setMinorAxis(double minorAxis);
		void setAxisRatio(double axisRatio);
		void setStartAngle(double startAngle);
		void setEndAngle(double endAngle);
		void setMajorAxisVectorX(double majorAxisVectorX);
		void setMajorAxisVectorY(double majorAxisVectorY);

	private:
		double centerX;
		double centerY;
		double majorAxisVectorX;
		double majorAxisVectorY;
		double axisRatio;
		double startAngle;
		double endAngle;
	
	};
}

#endif // CAD__CADELLIPSE_H
