/***************************************************************************
 *                                                                         *
 *   cad/cadlayer.h                                                        *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__CADLAYER_H
#define CAD__CADLAYER_H

#include "cadpen.h"

#include <qstring.h>

namespace cad
{
	class CADLayerList;
	
	/**
	 * CADLayer stores the properties of a Layer
	 * @author Christoph Permes
	 */
	class CADLayer
	{
	public:
		/**
		 * Create a layer with the given attributes
		 */
		CADLayer(QString name, CADPen pen = CADPen(CADColor::WHITE, "CONTINUOS"), bool frozen = false, bool locked = false);
		/** Destructor */
		~CADLayer();

		/** @return the layer name */
		QString getName() const
		{ return name; }
		/** @return the default pen */
		CADPen getPen() const
		{ return pen; }
		/** @return the frozen flag */
		bool getFrozen() const
		{ return frozen; }
		/** @return the locked flag */
		bool getLocked() const
		{ return locked; }
		
		/** set the layer name */
		void setName(QString name)
		{ this->name = name; }
		/** set the default pen */
		void setPen(CADPen pen)
		{ this->pen = pen; }
		/** set the frozen flag */
		void setFrozen(bool frozen)
		{ this->frozen = frozen; }
		/** set the locked flag */
		void setLocked(bool locked)
		{ this->locked = locked; }
		
		/** freezes the layer */
		void freeze() { frozen = true; }
		/** thaws the layer */
		void thaw() { frozen = false; }
		/** locks the layer */
		void lock() { locked = true; }
		/** unlocks the layer */
		void unlock() { locked = false; }
		
		//friend class CADLayerList;

	private:
		//! layer name
		QString name;
		//! default pen for this layer
		CADPen pen;
		//! frozen flag
		bool frozen;
		//! locked flag
		bool locked;
		
	};
}

#endif // CAD__CADLAYER_H
