/***************************************************************************
 *                                                                         *
 *   cad/cadlayerlist.h                                                    *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__CADLAYERLIST_H
#define CAD__CADLAYERLIST_H

#include "cadlayer.h"
#include "../util/exception.h"

#include <vector>

using namespace std;

namespace cad
{
	using util::Exception;
	
	/**
	 * CADLayerList manages the layers of a drawing
	 * @author Christoph Permes
	 */
	class CADLayerList
	{
	public:
		/**
		 * Create an CADLayerList with the layer "0"
		 */
		CADLayerList();
		/** Destructor */
		~CADLayerList();

		/** @return the layer at given index */
		CADLayer getLayer(int index) const throw (Exception);
		/** @return the layer with the given name */
		CADLayer getLayer(QString name) const throw (Exception);
		/** @return the number of layers */
		int getCount() const
		{ return layerList.size(); }
		/** @return the active layer index */
		int getActive() const
		{ return active; }
		
		/** set the active layer to layerList[index] */
		void setActive(int index) throw (Exception);
		/** set the layer with the given name as active layer */
		void setActive(QString name) throw (Exception);
		
		/** add layer to list if no layer with this name exists */
		void add(CADLayer layer) throw (Exception);
		/** remove layer at given index */
		void remove(int index) throw (Exception);
		/** remove layer with the given name */
		void remove(QString name) throw (Exception);
		/** update layer with the given index */
		void update(int index, CADLayer layer) throw (Exception);
		/** update layer with the given name */
		void update(QString name, CADLayer) throw (Exception);
		/**
		 * @return index of layer with the given name, if layer doesn't
		 * exists return -1
		 */
		int find(QString name) const;

	private:
		//! the layer list
		vector<CADLayer> layerList;
		//! the active layer
		int active;
		
	};
}

#endif // CAD__CADLAYERLIST_H
