/***************************************************************************
 *                                                                         *
 *   cad/shapes/cadline.cpp                                                *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "cadline.h"

#include <cmath>

using namespace cad;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CADLine::CADLine(QString layer, double startX, double startY, double endX,
	double endY)
{
	this->startX = startX;
	this->startY = startY;
	this->endX = endX;
	this->endY = endY;
}

CADLine::~CADLine()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

double CADLine::getStartX() const
{
	return startX;
}

double CADLine::getStartY() const
{
	return startY;
}

double CADLine::getEndX() const
{
	return endX;
}

double CADLine::getEndY() const
{
	return endY;
}

double CADLine::getLength() const
{
	return sqrt(pow(getDeltaX(), 2) + pow(getDeltaY(), 2));
}

double CADLine::getAngle() const
{
	if (getDeltaX() == 0.0)
		return 0.0;
	return atan(getDeltaY()/getDeltaX()) * (180/(4*atan(1.0)));
}

double CADLine::getDeltaX() const
{
	return endX - startX;
}

double CADLine::getDeltaY() const
{
	return endY - startY;
}

void CADLine::setStart(double x, double y)
{
	startX = x;
	startY = y;
}

void CADLine::setStartX(double x)
{
	startX = x;
}

void CADLine::setStartY(double y)
{
	startY = y;
}

void CADLine::setEnd(double x, double y)
{
	endX = x;
	endY = y;
}

void CADLine::setEndX(double x)
{
	endX = x;
}

void CADLine::setEndY(double y)
{
	endY = y;
}

// EOF
