/***************************************************************************
 *                                                                         *
 *   cad/cadlinetype.cpp                                                   *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "cadlinetype.h"

#include <cmath>

using namespace std;

using cad::CADLinetype;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/**
 * Create a linetype with the given attributes
 */
CADLinetype::CADLinetype(QString name, QString descriptiveText, vector<double> elements)
{
	setName(name);
	setDescriptiveText(descriptiveText);
	setElements(elements);
}

/** Destructor */
CADLinetype::~CADLinetype()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the total pattern length */
double CADLinetype::getTotalLength() const
{
	double totalLength = 0.0;
	for (int i = 0; i < elements.size(); i++)
		totalLength += fabs(elements.at(i));
	return totalLength;
}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

/**
 * @return true if the linetype has no name, descriptive text and
 * no elements
 */
bool CADLinetype::empty()
{
	if ((name == QString::null) && (descriptiveText == QString::null) && (elements.size() == 0))
		return true;
	return false;
}

// EOF
