/***************************************************************************
 *                                                                         *
 *   cad/cadlinetypelist.cpp                                               *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "cadlinetypelist.h"

using cad::CADLinetype;
using cad::CADLinetypeList;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/**
 * Constructor
 * Create an empty linetype list
 */
CADLinetypeList::CADLinetypeList()
{

}

/** Destructor */
CADLinetypeList::~CADLinetypeList()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return linetype at index */
CADLinetype CADLinetypeList::getLinetype(int index) const
{
	if ((index >= 0) && (index < linetypes.size()))
		return linetypes.at(index);
	return CADLinetype();
}

/** @return linetype with given name */
CADLinetype CADLinetypeList::getLinetype(QString name) const
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

/**
 * add a linetype to the list
 * @return true if linetype has been added to the list
 * @param overwrite: true if existing linetype with same name 
 *                   should be replaced
 */
bool CADLinetypeList::add(CADLinetype linetype, bool overwrite)
{
	bool exists = false;
	int i;
	for (i = 0; i<linetypes.size(); i++)
		if (linetypes.at(i).getName() == linetype.getName())
		{
			exists = true;
			if (overwrite)
			{
				linetypes.at(i) = linetype;
				return true;
			}
			return false;
		}
	linetypes.push_back(linetype);
	return true;
}

/**
 * remove linetype with the given name
 * @return true if linetype has been removed successfully
 */
bool CADLinetypeList::remove(QString name)
{
	int index = find(name);
	if (index != -1)
	{
		linetypes.erase(linetypes.begin()+index);
		return true;
	}
	return false;
}

/**
 * searches a linetype with the given name
 * @return the index of the linetype, -1 if no linetype doesn't exist
 */
int CADLinetypeList::find(QString name)
{
	for (int i = 0; i<linetypes.size(); i++)
	{
		if (linetypes.at(i).getName() == name)
			return i;
	}
	return -1;
}

// EOF
