/***************************************************************************
 *                                                                         *
 *   cad/cadlinetypelist.h                                                 *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__CADLINETYPELIST_H
#define CAD__CADLINETYPELIST_H

#include "cadlinetype.h"
#include <vector>

using namespace std;

namespace cad
{
	/**
	 * CADLinetypeList is a list of Linetypes
	 * @author Christoph Permes
	 */
    class CADLinetypeList
    {
    public:
		/**
		 * Create an empty linetype list
		 */
		CADLinetypeList();
		/** Destructor */
		~CADLinetypeList();
		
		/** @return linetype at index */
		CADLinetype getLinetype(int index) const;
		/** @return linetype with given name */
		CADLinetype getLinetype(QString name) const;
		/** @return number of linetypes */
		int getCount() const
		{ return linetypes.size(); }
		
		/**
		 * add a linetype to the list
		 * @return true if linetype has been added to the list
		 * @param overwrite: true if existing linetype with same name 
		 *                   should be replaced
		 */
		bool add(CADLinetype linetype, bool overwrite = false);
		/**
		 * remove linetype with the given name
		 * @return true if linetype has been removed successfully
		 */
		bool remove(QString name);
		/**
		 * searches a linetype with the given name
		 * @return the index of the linetype, -1 if no linetype doesn't exist
		 */
		int find(QString name);

    private:
		//! linetype list
		vector<CADLinetype> linetypes;

    };
}

#endif // CAD__CADLINETYPE_H
