/***************************************************************************
 *                                                                         *
 *   cad/cadpen.h                                                          *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__CADPEN_H
#define CAD__CADPEN_H

#include "cadcolor.h"
#include "cadlinetype.h"

namespace cad
{
	/**
	 * CADPen stores attributes needed for painting like color, linetype, ...
	 *
	 * @author Christoph Permes
	 */
	class CADPen
	{
	public:
		/** Creates a default CADPen with the given attributes */
		CADPen(CADColor color = CADColor::BYLAYER, QString linetype = "BYLAYER", double linetypeFactor = 1.0);
		/** Destructor */
		virtual ~CADPen();
		
		/** @return the pen color */
		CADColor getColor() const
		{ return color; }
		/** @return the pen linetype */
		QString getLinetype() const
		{ return linetype; }
		/** @return the pen linetypeFactor */
		double getLinetypeFactor() const
		{ return linetypeFactor; }
		
		/** set the pen color */
		void setColor(CADColor color)
		{ this->color = color; }
		/** set the pen linetype */
		void setLinetype(QString linetype)
		{ this->linetype = linetype; }
		/** set the pen linetypefactor */
		void setLinetypeFactor(double linetypeFactor)
		{
			if (linetypeFactor != 0.0)
				this->linetypeFactor = linetypeFactor;
			else this->linetypeFactor = 1.0;
		}
		
	private:
		//! pen color
		CADColor color;
		//! pen linetype
		QString linetype;
		//! pen linetypeFactor
		double linetypeFactor;
	};
}

#endif // CAD__CADPEN_H
