/***************************************************************************
 *                                                                         *
 *   gui/dialogs/colordialog.h                                             *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 
#ifndef GUI__DIALOGS__COLORDIALOG_H
#define GUI__DIALOGS__COLORDIALOG_H

#include <qdialog.h>
#include <qgroupbox.h>
#include <qlineedit.h>
#include <qlabel.h>
#include <qpushbutton.h>

#include "../widgets/colorpalette.h"
#include "../widgets/graypalette.h"
#include "../widgets/completepalette.h"
#include "../../cad/cadcolor.h"
#include "../../cad/cadentity.h"
#include "../../util/exception.h"



namespace gui
{
	namespace dialogs
	{
		using namespace gui::widgets;
		using cad::CADColor;
		using cad::CADEntity;
		using util::Exception;
		
		/**
		 * ColorDialog is a dialog for selecting a color
		 * @author Christoph Permes
		 */
		class ColorDialog : public QDialog
		{
		Q_OBJECT
		public:
			/**
			 * Create a ColorDialog with the given color selected
			 * @param layer: if layer is QString::null BYLAYER and BYBLOCK
			 * will be disabled
			 */
			ColorDialog(CADColor color, QString layer, QWidget* parent = 0, const char* name = 0);
			/** Destructor */
			~ColorDialog();
			
			/** @return the selected color */
			CADColor getColor();
			
			/** Converts a color name to the color value */
			static CADColor nameToValue(QString name) throw (Exception);
			/** Converts a color value to the color name */
			static QString valueToName(CADColor color);
			
		private:
			QGroupBox* standardGroup;
			QGroupBox* grayGroup;
			QGroupBox* assignmentGroup;
			QGroupBox* completeGroup;
			ColorPalette* standardColors;
			GrayPalette* grayColors;
			CompletePalette* completeColors;
			QPushButton* byLayer;
			QPushButton* byBlock;
			QLabel* colorLabel;
			QLineEdit* colorName;
			QWidget* colorDisplay;
			QPushButton* ok;
			QPushButton* cancel;
			
			CADColor color;
			QString layer;
		
		private:
			/** update the color display (name, color) */
			void updateColorDisplay();
		
		private slots:
			void sltByLayer();
			void sltByBlock();
			void sltColorChanged(int color);
			void sltColorNameReturn();
			void sltOKClick();
			void sltCancelClick();
		};
	}
}

#endif // GUI__DIALOGS__COLORDIALOG_H
