/***************************************************************************
 *                                                                         *
 *   gui/dialogs/layersdialog.cpp                                          *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "layerdialog.h"
#include "colordialog.h"
#include "linetypedialog.h"
#include "../../io/drawingmanager.h"
#include "../../util/exception.h"

#include <qmessagebox.h>

using namespace gui::dialogs;
using cad::CADLayerList;
using cad::CADLayer;
using io::DrawingManager;
using util::Exception;

/* TRANSLATOR gui::dialogs::LayerDialog */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/**
 * Constructor
 * Create a LayerDialog which contains the given layerlist
 */
LayerDialog::LayerDialog(CADLayerList layerList, QWidget* parent, char* name):
QDialog(parent, name)
{
	this->layerList = layerList;
	this->setCaption(tr("Layers"));
	this->setFixedSize(540, 265);
	currentLayer = new QLabel(this);
	currentLayer->setGeometry(10, 5, 250, 25);
	
	layerView = new QListView(this);
	layerView->setGeometry(10, 35, 360, 150);
	layerView->setMultiSelection(false);
	layerView->addColumn(tr("Name"), 100);
	layerView->addColumn(tr("State"), 50);
	layerView->addColumn(tr("Color"), 50);
	layerView->addColumn(tr("Linetype"), 150);

	newLayer = new QPushButton(this);
	newLayer->setGeometry(10, 190, 85, 30);
	newLayer->setText(tr("&New"));
	connect(newLayer, SIGNAL(clicked()), this, SLOT(sltNewLayerClick()));

	deleteLayer = new QPushButton(this);
	deleteLayer->setGeometry(100, 190, 85, 30);
	deleteLayer->setText(tr("&Delete"));
	connect(deleteLayer, SIGNAL(clicked()), this, SLOT(sltDeleteLayerClick()));

	setCurrent = new QPushButton(this);
	setCurrent->setGeometry(190, 190, 85, 30);
	setCurrent->setText(tr("&Set Active"));
	connect(setCurrent, SIGNAL(clicked()), this, SLOT(sltSetCurrentClick()));

	renameLayer = new QPushButton(this);
	renameLayer->setGeometry(280, 190, 85, 30);
	renameLayer->setText(tr("&Rename"));
	connect(renameLayer, SIGNAL(clicked()), this, SLOT(sltRenameLayerClick()));

	layerName = new QLineEdit(this);
	layerName->setGeometry(10, 225, 360, 25);

	freeze = new QPushButton(this);
	freeze->setGeometry(375, 30, 75, 30);
	freeze->setText(tr("&Freeze"));
	connect(freeze, SIGNAL(clicked()), this, SLOT(sltFreezeClick()));

	thaw = new QPushButton(this);
	thaw->setGeometry(455, 30, 75, 30);
	thaw->setText(tr("&Thaw"));
	connect(thaw, SIGNAL(clicked()), this, SLOT(sltThawClick()));

	lock = new QPushButton(this);
	lock->setGeometry(375, 65, 75, 30);
	lock->setText(tr("Loc&k"));
	connect(lock, SIGNAL(clicked()), this, SLOT(sltLockClick()));

	unlock = new QPushButton(this);
	unlock->setGeometry(455, 65, 75, 30);
	unlock->setText(tr("&Unlock"));
	connect(unlock, SIGNAL(clicked()), this, SLOT(sltUnlockClick()));

	color = new QPushButton(this);
	color->setGeometry(375, 100, 155, 30);
	color->setText(tr("Co&lor"));
	connect(color, SIGNAL(clicked()), this, SLOT(sltColorClick()));

	linetype = new QPushButton(this);
	linetype->setGeometry(375, 135, 155, 30);
	linetype->setText(tr("Linet&ype"));
	connect(linetype, SIGNAL(clicked()), this, SLOT(sltLinetypeClick()));

	ok = new QPushButton(this);
	ok->setGeometry(375, 190, 155, 30);
	ok->setText(tr("&OK"));
	ok->setDefault(true);
	connect(ok, SIGNAL(clicked()), this, SLOT(sltOKClick()));

	cancel = new QPushButton(this);
	cancel->setGeometry(375, 225, 155, 30);
	cancel->setText(tr("&Cancel"));
	connect(cancel, SIGNAL(clicked()), this, SLOT(sltCancelClick()));

	updateLayerView();
	layerView->setSelected(layerView->firstChild(), true);
}

/** Destructor */
LayerDialog::~LayerDialog()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the layerlist */
CADLayerList LayerDialog::getLayerList()
{
	return layerList;
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

/** update the layerlist display */
void LayerDialog::updateLayerView()
{
	layerView->clear();
	for (int i = 0; i<layerList.getCount(); i++)
	{
		CADLayer layer = layerList.getLayer(i);
		QListViewItem* item = new QListViewItem(layerView, layer.getName(),  QString(layer.getFrozen()?"f ":". ") + QString(layer.getLocked()?"l ":". "), ColorDialog::valueToName(layer.getPen().getColor().getValue()), layer.getPen().getLinetype());
		layerView->insertItem(item);
	}
	
	currentLayer->setText(tr("Active Layer: ") + layerList.getLayer(layerList.getActive()).getName());
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void LayerDialog::sltNewLayerClick()
{
	if (layerName->text().isEmpty())
	{
		QMessageBox::warning(this, tr("Error"), tr("Please insert a layer name."));
		return;
	}

	try
	{
		layerList.add(CADLayer(layerName->text()));
		updateLayerView();
	}
	catch (Exception e)
	{
		QMessageBox::information(this, tr("Error"), e.getError());
	}
}

void LayerDialog::sltDeleteLayerClick()
{
	if (layerView->selectedItem() != 0)
	{
		try
		{
			layerList.remove(layerView->selectedItem()->text(0));
			updateLayerView();
		}
		catch (Exception e)
		{
			QMessageBox::information(this, tr("Error"), e.getError());
		}
	}
	else
		QMessageBox::information(this, tr("Error"), tr("No layer has been selected."));
}

void LayerDialog::sltSetCurrentClick()
{
	if (layerView->selectedItem() != 0)
	{
		try
		{
			layerList.setActive(layerView->selectedItem()->text(0));
			updateLayerView();
		}
		catch (Exception e)
		{
			QMessageBox::information(this, tr("Error"), e.getError());	
		}
	}
	else
		QMessageBox::information(this, tr("Error"), tr("No layer has been selected."));
}

void LayerDialog::sltRenameLayerClick()
{
	if (layerView->selectedItem() != 0)
	{
		try
		{
			QString name = layerView->selectedItem()->text(0);
			CADLayer layer = layerList.getLayer(name);
			layer.setName(layerName->text());
			layerList.update(name, layer);
			rm.add(layerView->selectedItem()->text(0), layer.getName());
			updateLayerView();
		}
		catch (Exception e)
		{
			QMessageBox::information(this, tr("Error"), e.getError());
		}
	}
	else
		QMessageBox::information(this, tr("Error"), tr("No layer has been selected."));
}

void LayerDialog::sltFreezeClick()
{
	if (layerView->selectedItem() != 0)
	{
		try
		{
			CADLayer layer = layerList.getLayer(layerView->selectedItem()->text(0));
			layer.freeze();
			layerList.update(layer.getName(), layer);
			updateLayerView();
		}
		catch (Exception e)
		{
			QMessageBox::warning(this, tr("Error"), e.getError());	
		}
	}
	else
		QMessageBox::warning(this, tr("Error"), tr("No layer has been selected."));
}

void LayerDialog::sltThawClick()
{
	if (layerView->selectedItem() != 0)
	{
		try
		{
			CADLayer layer = layerList.getLayer(layerView->selectedItem()->text(0));
			layer.thaw();
			layerList.update(layer.getName(), layer);
			updateLayerView();
		}
		catch (Exception e)
		{
			QMessageBox::warning(this, tr("Error"), e.getError());	
		}
	}
	else
		QMessageBox::warning(this, tr("Error"), tr("No layer has been selected."));
}

void LayerDialog::sltLockClick()
{
	if (layerView->selectedItem() != 0)
	{
		try
		{
			CADLayer layer = layerList.getLayer(layerView->selectedItem()->text(0));
			layer.lock();
			layerList.update(layer.getName(), layer);
			updateLayerView();
		}
		catch (Exception e)
		{
			QMessageBox::warning(this, tr("Error"), e.getError());	
		}
	}
	else
		QMessageBox::warning(this, tr("Error"), tr("No layer has been selected."));
}

void LayerDialog::sltUnlockClick()
{
	if (layerView->selectedItem() != 0)
	{
		try
		{
			CADLayer layer = layerList.getLayer(layerView->selectedItem()->text(0));
			layer.unlock();
			layerList.update(layer.getName(), layer);
			updateLayerView();
		}
		catch (Exception e)
		{
			QMessageBox::warning(this, tr("Error"), e.getError());	
		}
	}
	else
		QMessageBox::warning(this, tr("Error"), tr("No layer has been selected."));
}

void LayerDialog::sltColorClick()
{
	if (layerView->selectedItem() != 0)
	{
		try
		{
			CADLayer layer = layerList.getLayer(layerView->selectedItem()->text(0));
			ColorDialog dlg(layer.getPen().getColor(), QString::null, this);
			if (dlg.exec())
			{
				layer.setPen(CADPen(dlg.getColor(), layer.getPen().getLinetype()));
				layerList.update(layer.getName(), layer);
				updateLayerView();
			}
		}
		catch (Exception e)
		{
			QMessageBox::warning(this, tr("Error"), e.getError());	
		}
	}
	else
		QMessageBox::warning(this, tr("Error"), tr("No layer has been selected."));
}

void LayerDialog::sltLinetypeClick()
{
	if (layerView->selectedItem() != 0)
	{
		try
		{
			CADLayer layer = layerList.getLayer(layerView->selectedItem()->text(0));
			LinetypeDialog dlg(DrawingManager::getInstance()->getDrawing()->getLinetypeList(), false, this);
			dlg.setLinetype(layer.getPen().getLinetype());
			if (dlg.exec())
			{
				layer.setPen(CADPen(layer.getPen().getColor(), dlg.getLinetype()));
				DrawingManager::getInstance()->getDrawing()->updateLinetypeList(dlg.getLinetypeList());
				layerList.update(layer.getName(), layer);
				updateLayerView();
			}
		}
		catch (Exception e)
		{
			QMessageBox::warning(this, tr("Error"), e.getError());	
		}
	}
	else
		QMessageBox::warning(this, tr("Error"), tr("No layer has been selected."));
}

void LayerDialog::sltOKClick()
{
    accept();
}

void LayerDialog::sltCancelClick()
{
    reject();
}

//EOF
