/***************************************************************************
 *                                                                         *
 *   gui/dialogs/layerdialog.h                                             *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GUI__DIALOGS__LAYERDIALOG_H
#define GUI__DIALOGS__LAYERDIALOG_H

#include <qdialog.h>
#include <qlabel.h>
#include <qpushbutton.h>
#include <qlistview.h>
#include <qlineedit.h>

#include "../../cad/cadlayerlist.h"
#include "../../util/layerrenamingmanager.h"

using cad::CADLayerList;

namespace gui
{
	namespace dialogs
	{
		using util::LayerRenamingManager;
	
		/**
		 * LayersDialog is a Dialog for managing layers
		 * @author Christoph Permes
		 */
		class LayerDialog : public QDialog
		{
		Q_OBJECT
		public:
			/**
			 * Create a LayerDialog which contains the given layerlist
			 */
			LayerDialog(CADLayerList layerList, QWidget* parent = 0, char* name = 0);
			/** Destructor */
			~LayerDialog();
			
			/** @return the layerlist */
			CADLayerList getLayerList();
			/** @return the renaming manager */
			LayerRenamingManager getLayerRenamingManager() const
			{ return rm; }
	
		private:
			QLabel* currentLayer;
			QListView* layerView;
			QPushButton* newLayer;
			QPushButton* deleteLayer;
			QPushButton* setCurrent;
			QPushButton* renameLayer;
			QLineEdit* layerName;
			QPushButton* freeze;
			QPushButton* thaw;
			QPushButton* lock;
			QPushButton* unlock;
			QPushButton* color;
			QPushButton* linetype;
			QPushButton* ok;
			QPushButton* cancel;
			
			//! the layerlist
			CADLayerList layerList;
			//! the layer renaming manager
			LayerRenamingManager rm;
			
			/** update the layerlist display */
			void updateLayerView();
	
		private slots:
			void sltNewLayerClick();
			void sltDeleteLayerClick();
			void sltSetCurrentClick();
			void sltRenameLayerClick();
			void sltFreezeClick();
			void sltThawClick();
			void sltLockClick();
			void sltUnlockClick();
			void sltColorClick();
			void sltLinetypeClick();
			void sltOKClick();
			void sltCancelClick();
	
		};
	}
}

#endif // GUI__DIALOGS__LAYERDIALOG_H
