/***************************************************************************
 *                                                                         *
 *   gui/dialogs/layerselectiondialog.cpp                                  *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "layerselectiondialog.h"

#include "colordialog.h"
#include "../../cad/cadlayer.h"
#include <qmessagebox.h>

using gui::dialogs::LayerSelectionDialog;

/* TRANSLATOR gui::dialogs::LayerSelectionDialog */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/**
 * Constructor
 * Create a layer selection dialog for selecting a layer from 
 * the given CADLayerList
 */
LayerSelectionDialog::LayerSelectionDialog(CADLayerList layerList, QWidget* parent, char* name):
QDialog(parent, name)
{
	this->setCaption(tr("Choose Layer"));
	this->setFixedSize(380, 210);
	this->layerList = layerList;
	
	layerView = new QListView(this);
	layerView->setGeometry(10, 10, 360, 150);
	layerView->setMultiSelection(false);
	layerView->addColumn(tr("Name"), 100);
	layerView->addColumn(tr("State"), 50);
	layerView->addColumn(tr("Color"), 50);
	layerView->addColumn(tr("Linetype"), 150);
	updateLayerView();

	ok = new QPushButton(this);
	ok->setGeometry(10, 170, 100, 30);
	ok->setText(tr("&OK"));
	ok->setDefault(true);
	connect(ok, SIGNAL(clicked()), this, SLOT(sltOKClick()));

	cancel = new QPushButton(this);
	cancel->setGeometry(120, 170, 100, 30);
	cancel->setText(tr("&Cancel"));
	connect(cancel, SIGNAL(clicked()), this, SLOT(sltCancelClick()));
}

/** Destructor */
LayerSelectionDialog::~LayerSelectionDialog()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the name of the selected layer */
QString LayerSelectionDialog::getLayer() const
{
	if (layerView->selectedItem() == 0)
		return QString::null;
	return layerView->selectedItem()->text(0);
}

/** set the selected layer */
void LayerSelectionDialog::setLayer(QString name)
{
	for (QListViewItem* i = layerView->firstChild(); i != layerView->lastItem(); i = i->nextSibling())
	{
		if (i->text(0) == name)
		{
			layerView->setSelected(i, true);
			break;
		}
	}
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void LayerSelectionDialog::updateLayerView()
{
	layerView->clear();
	for (int i = 0; i<layerList.getCount(); i++)
	{
		CADLayer layer = layerList.getLayer(i);
		QListViewItem* item = new QListViewItem(layerView, layer.getName(), 
			QString(layer.getFrozen()?"f ":". ") +
			QString(layer.getLocked()?"l ":". "), 
			ColorDialog::valueToName(layer.getPen().getColor().getValue()), 
			layer.getPen().getLinetype());
		layerView->insertItem(item);
	}
	layerView->setSelected(layerView->firstChild(), true);
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void LayerSelectionDialog::sltOKClick()
{
	if (layerView->selectedItem() != 0)
	{
	    accept();
	}
	else
		QMessageBox::information(this, tr("Error"), tr("Please select a Layer."));
}

void LayerSelectionDialog::sltCancelClick()
{
    reject();
}

// EOF
