/***************************************************************************
 *                                                                         *
 *   gui/dialogs/layerselectiondialog.h                                    *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GUI__DIALOGS__LAYERSELECTIONDIALOG_H
#define GUI__DIALOGS__LAYERSELECTIONDIALOG_H

#include <qdialog.h>
#include <qpushbutton.h>
#include <qlistview.h>

#include "../../cad/cadlayerlist.h"

using namespace cad;

namespace gui
{
	namespace dialogs
	{
		/**
		 * LayerSelectionDialog is a dialog for selecting a layer
		 * @author Christoph Permes
		 */
		class LayerSelectionDialog : public QDialog
		{
		Q_OBJECT
		public:
			/**
			 * Create a layer selection dialog for selecting a layer from 
			 * the given CADLayerList
			 */
			LayerSelectionDialog(CADLayerList layerList, QWidget* parent = 0, 
				char* name = 0);
			/** Destructor */
			~LayerSelectionDialog();
			
			/** @return the name of the selected layer */
			QString getLayer() const;
			/** set the selected layer */
			void setLayer(QString name);
	
		private:
			CADLayerList layerList;
			QListView* layerView;
			QPushButton* ok;
			QPushButton* cancel;
	
			void updateLayerView();
	
		private slots:
			void sltOKClick();
			void sltCancelClick();
		
		};
	}
}

#endif // GUI__DIALOGS__LAYERSELECTIONDIALOG_H
