/***************************************************************************
 *                                                                         *
 *   gui/dialogs/linetypedialog.cpp                                        *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 
#include "linetypedialog.h"

#include "linetypeloaddialog.h"

#include <qmessagebox.h>

using gui::dialogs::LinetypeDialog;
using gui::dialogs::LinetypeLoadDialog;
using namespace cad;

/* TRANSLATOR gui::dialogs::LinetypeDialog */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/**
 * Constructor
 * Create a linetype dialog for selecting one from the given 
 * CADLinetypeList
 * @param allowByLayer: true if linetype can be BYLAYER
 */
LinetypeDialog::LinetypeDialog(CADLinetypeList linetypeList, bool allowByLayer, QWidget* parent, const char* name) : LinetypeDialogBase(parent, name)
{
	this->setCaption(tr("Choose Linetype"));
	
	load = new QPushButton(this);
	load->setGeometry(210, 210, 90, 30);
	load->setText(tr("&Load"));
	connect(load, SIGNAL(clicked()), this, SLOT(sltLoadClick()));
	
	this->linetypeList = linetypeList;
	this->allowByLayer = allowByLayer;
	updateView();
}

/** Destructor */
LinetypeDialog::~LinetypeDialog()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the selected linetype */
QString LinetypeDialog::getLinetype() const
{
	return linetypeView->selectedItem()->text(0);
}

/** set the selected linetype */
void LinetypeDialog::setLinetype(QString linetype)
{
	QListViewItem* selected = linetypeView->findItem(linetype, 0);
	if (selected != 0)
		selected->setSelected(true);
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void LinetypeDialog::sltOKClick()
{
	if (linetypeView->selectedItem() == 0)
		QMessageBox::warning(this, tr("Error"), tr("No Linetype has been selected."));
	else
		accept();
}

void LinetypeDialog::sltLoadClick()
{
	LinetypeLoadDialog dlg(this);
	if (dlg.exec())
	{
		CADLinetypeList loaded = dlg.getLinetypes();
		for (int i = 0; i<loaded.getCount(); i++)
		{
			if (linetypeList.add(loaded.getLinetype(i)) == false)
				if (QMessageBox::question(
					this,
					tr("Replace Linetypes"), 
					tr("Linetype %1 already exists. Replace?").arg("\""+ loaded.getLinetype(i).getName()+ "\""),
					QMessageBox::Yes, QMessageBox::No) == QMessageBox::Yes)
					linetypeList.add(loaded.getLinetype(i), true);
		}
		
		updateView();
	}
}

// EOF
