/***************************************************************************
 *                                                                         *
 *   gui/dialogs/linetypedialogbase.cpp                                    *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 
#include "linetypedialogbase.h"

#include <qmessagebox.h>

using gui::dialogs::LinetypeDialogBase;
using namespace cad;

/* TRANSLATOR gui::dialogs::LinetypeDialogBase */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/** Constructor */
LinetypeDialogBase::LinetypeDialogBase(QWidget* parent, const char* name) : 
QDialog(parent, name)
{
	this->setFixedSize(470, 250);
	
	linetypeView = new QListView(this);
	linetypeView->setGeometry(10, 10, 450, 190);
	linetypeView->setSorting(-1);
	linetypeView->addColumn(tr("Name"), 150);
	linetypeView->addColumn(tr("Description"), 280);

	ok = new QPushButton(this);
	ok->setGeometry(10, 210, 90, 30);
	ok->setText(tr("&OK"));
	ok->setDefault(true);
	connect(ok, SIGNAL(clicked()), this, SLOT(sltOKClick()));
	
	cancel = new QPushButton(this);
	cancel->setGeometry(110, 210, 90, 30);
	cancel->setText(tr("&Cancel"));
	connect(cancel, SIGNAL(clicked()), this, SLOT(sltCancelClick()));
	
	allowByLayer = true;
}

/** Destructor */
LinetypeDialogBase::~LinetypeDialogBase()
{
	
}

/***************************************************************************
 * Protected Methods                                                       *
 ***************************************************************************/

void LinetypeDialogBase::updateView()
{
	linetypeView->clear();
	
	for (int i = linetypeList.getCount()-1; i>=0; i--)
	{
		CADLinetype lt = linetypeList.getLinetype(i);
		if ((!allowByLayer) && ((lt.getName() == "BYLAYER") || (lt.getName() == "BYBLOCK")))
			continue;
		QListViewItem* item = new QListViewItem(linetypeView, lt.getName(), lt.getDescriptiveText());
	}
}

/***************************************************************************
 * Protected Slots                                                         *
 ***************************************************************************/

void LinetypeDialogBase::sltOKClick()
{
	accept();
}

void LinetypeDialogBase::sltCancelClick()
{
	reject();
}

// EOF
