/***************************************************************************
 *                                                                         *
 *   gui/dialogs/linetypeloaddialog.cpp                                    *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 
#include "linetypeloaddialog.h"

#include <qmessagebox.h>
#include <qapplication.h>
#include <qfile.h>
#include <qfiledialog.h>
#include <qtextstream.h>
#include "../../exporters/xml/xmllinetypelist.h"

using exporters::xml::XmlLinetypeList;

using gui::dialogs::LinetypeLoadDialog;
using namespace cad;
using util::Exception;

/* TRANSLATOR gui::dialogs::LinetypeLoadDialog */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/** Constructor */
LinetypeLoadDialog::LinetypeLoadDialog(QWidget* parent, const char* name) : 
LinetypeDialogBase(parent, name)
{
	this->setCaption(tr("Load Linetypes"));

	file = new QPushButton(this);
	file->setGeometry(210, 210, 90, 30);
	file->setText(tr("&File"));
	connect(file, SIGNAL(clicked()), this, SLOT(sltFileClick()));
	
	linetypeView->setSelectionMode(QListView::Extended);
	try
	{
		this->linetypeList = loadFromFile(qApp->applicationDirPath() + "/../share/default.clt");
		updateView();
	}
	catch (Exception e)
	{
		QMessageBox::information(this, tr("Error"), e.getError());
	}

/*	// Write
	XmlLinetypeList x;
	QDomDocument doc = x.xmlExport(IOInterface::getInstance()
		->getDrawing()->getLinetypeList());
	QFile file ("/home/cpermes/default.clt");
	file.open(IO_WriteOnly);
	QTextStream stream(&file);
	stream << doc.toString();
	file.close();*/
/*	// Read
	QDomDocument doc;
	QFile file("/home/cpermes/default.ltx");
	file.open(IO_ReadOnly);
	doc.setContent(&file);
	file.close();
	XmlLinetypeList x;
	linetypes = x.xmlImport(doc.documentElement()).getLinetypes();*/

//	for (int i = 0; i<linetypes.size(); i++)
//	{
//		CADLinetype lt = linetypes.at(i);
//		linetypeList->insertItem(new QListViewItem(linetypeList, lt.getName(),
//			lt.getDescriptiveText()));
//	}
}

LinetypeLoadDialog::~LinetypeLoadDialog()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

CADLinetypeList LinetypeLoadDialog::getLinetypes() const
{
	CADLinetypeList loaded;
	
	QListViewItem* selected = linetypeView->firstChild();
	for (int i = 0; selected != 0; i++)
	{
		if (selected->isSelected())
			loaded.add(linetypeList.getLinetype(i));
		selected = selected->nextSibling();
	}
	return loaded;
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

/** loads a CADLinetypeList from a file */
CADLinetypeList LinetypeLoadDialog::loadFromFile(QString filename) throw (Exception)
{
	QDomDocument doc;
	QFile file(filename);
	if (!file.open(IO_ReadOnly))
		throw Exception(tr("File %1 doesn\'t exist.").arg(filename));
	doc.setContent(&file);
	file.close();
	XmlLinetypeList x;
	return x.xmlImport(doc.documentElement());
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void LinetypeLoadDialog::sltFileClick()
{
	QString path = QFileDialog::getOpenFileName("~/", 
		"ConstructCAD Linetypes (*.clt);;All Files (*.*)");
	if (!path.isEmpty())
	{
		try
		{
			CADLinetypeList linetypes = loadFromFile(path);
			if (linetypes.getCount() != 0)
			{
				this->linetypeList = linetypes;
				updateView();
			}
			else
				QMessageBox::information(this, tr("Error"), tr("File contains no valid ConstructCAD Linetypes."));
		}
		catch (Exception e)
		{
			QMessageBox::information(this, tr("Error"), e.getError());
		}
	}
}

// EOF
