/***************************************************************************
 *                                                                         *
 *   gui/dialogs/propertiesdialog.h                                        *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GUI__DIALOGS__PROPERTIESDIALOG_H
#define GUI__DIALOGS__PROPERTIESDIALOG_H

#include <qdialog.h>
#include <qwidget.h>

#include "../edit/propertiesedit.h"
#include "../edit/entityedit.h"
#include "../../cad/cadentity.h"

namespace gui
{
	namespace dialogs
	{
		using cad::CADEntity;
		using namespace gui::edit;
		
		/**
		 * PropertiesDialog is a dialog for editing the properties of entities
		 * or editing the active pen and layer settings
		 * @author Christoph Permes
		 */
	    class PropertiesDialog : public QDialog
	    {
		Q_OBJECT
	    public:
			/**
			 * Create a PropertiesDialog
			 * @param entitiy: if entity is 0 the dialog would edit the 
			 * active pen and layer settings, else the given entity is edited.
			 */
			PropertiesDialog(CADEntity* entity, QWidget* parent=0, 
				const char *name=0);
			/** Destructor */
			~PropertiesDialog();
			
			/** @return the edited entity */
			CADEntity* getEntity();
			
	    private:
	    	CADEntity* entity;
	    	PropertiesEdit* properties;
			EntityEdit* entityEdit;
			QPushButton* ok;
			QPushButton* cancel;
			
		private slots:
			void sltOK();
			void sltCancel();
			void sltSpecify();
		
	    };
	}
}

#endif // GUI__DIALOGS__PROPERTIESDIALOG_H
