/***************************************************************************
 *                                                                         *
 *   gui/edit/arcedit.cpp                                                  *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "arcedit.h"

#include <qmessagebox.h>

using namespace gui::edit;
using cad::CADArc;

/* TRANSLATOR gui::edit::ArcEdit */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

ArcEdit::ArcEdit(CADArc* arc, QWidget* parent, const char* name):
	EntityEdit(parent, name)
{
	this->resize(350, 180);
	this->arc = arc;
	
	centerEdit = new CoordinateEdit(this);
	centerEdit->setGeometry(0, 0, centerEdit->width(), centerEdit->height());
	centerEdit->setTitle(tr("Center"));
	connect(centerEdit, SIGNAL(changed(double&, double& )), this, SLOT(sltCenterChanged(double&, double& )));
	connect(centerEdit, SIGNAL(specifyPoint()), this, SLOT(sltCenterSpecify()));
	
	radiusEdit = new ValueEdit(this);
	radiusEdit->setGeometry(150, 0, radiusEdit->width(), radiusEdit->height());
	radiusEdit->setTitle(tr("Radius:"));
	connect(radiusEdit, SIGNAL(valueChanged(double&)), this, 
		SLOT(sltRadiusChanged(double&)));
	startAngleEdit = new ValueEdit(this);
	startAngleEdit->setGeometry(150, 30, startAngleEdit->width(), 
		startAngleEdit->height());
	startAngleEdit->setTitle(tr("Start Angle:"));
	connect(startAngleEdit, SIGNAL(valueChanged(double&)), this,
		SLOT(sltStartAngleChanged(double&)));
	endAngleEdit = new ValueEdit(this);
	endAngleEdit->setGeometry(150, 60, endAngleEdit->width(), 
		endAngleEdit->height());
	endAngleEdit->setTitle(tr("End Angle:"));
	connect(endAngleEdit, SIGNAL(valueChanged(double&)), this,
		SLOT(sltEndAngleChanged(double&)));

	angle = new QLabel(this);
	angle->setGeometry(150, 90, 105, 20);
	angle->setText(tr("Angle:"));
	angleDisplay = new QLabel(this);
	angleDisplay->setGeometry(260, 90, 90, 20);
	angleDisplay->setAlignment(AlignRight);
	length = new QLabel(this);
	length->setGeometry(150, 110, 105, 20);
	length->setText(tr("Length:"));
	lengthDisplay = new QLabel(this);
	lengthDisplay->setGeometry(260, 110, 90, 20);
	lengthDisplay->setAlignment(AlignRight);
	
	update();
}

ArcEdit::~ArcEdit()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the edited entity */
CADEntity* ArcEdit::getEntity() throw (Exception)
{
	qDebug("ArcEdit::getEntity()");
	arc->setCenterX(centerEdit->getX());
	arc->setCenterY(centerEdit->getY());
	arc->setRadius(radiusEdit->getValue());
	arc->setStartAngle(startAngleEdit->getValue());
	arc->setEndAngle(endAngleEdit->getValue());
	return arc;
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void ArcEdit::update()
{
	centerEdit->setCoordinate(arc->getCenterX(), arc->getCenterY());
	radiusEdit->setValue(arc->getRadius());
	startAngleEdit->setValue(arc->getStartAngle());
	endAngleEdit->setValue(arc->getEndAngle());
	QString text;
	text.sprintf("%1.4f", arc->getAngle());
	angleDisplay->setText(text);
	text.sprintf("%1.4f", arc->getLength());
	lengthDisplay->setText(text);
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void ArcEdit::sltCenterChanged(double &x, double &y)
{
	arc->setCenter(x, y);
	update();
}

void ArcEdit::sltCenterSpecify()
{
	emit specify();
}

void ArcEdit::sltRadiusChanged(double &value)
{
	arc->setRadius(value);
	update();
}

void ArcEdit::sltStartAngleChanged(double &value)
{
	arc->setStartAngle(value);
	update();
}

void ArcEdit::sltEndAngleChanged(double &value)
{
	arc->setEndAngle(value);
	update();
}

// EOF
