/***************************************************************************
 *                                                                         *
 *   gui/edit/arcedit.h                                                    *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GUI__EDIT__ARCEDIT_H
#define GUI__EDIT__ARCEDIT_H

#include "entityedit.h"
#include "coordinateedit.h"
#include "valueedit.h"
#include "../../cad/cadarc.h"

#include <qwidget.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qpushbutton.h>

namespace gui
{
	namespace edit
	{
		using cad::CADArc;
		
		/**
		 * ArcEdit is a widget for editing arcs
		 * @author Christoph Permes
		 */
		class ArcEdit : public EntityEdit
		{
		Q_OBJECT
		public:
			ArcEdit(CADArc* arc, QWidget* parent = 0, const char* name = 0);
			~ArcEdit();
			
			/** @return the edited entity */
			virtual CADEntity* getEntity() throw (Exception);
			
		private:
			CADArc* arc;
			CoordinateEdit* centerEdit;
			ValueEdit* radiusEdit;
			ValueEdit* startAngleEdit;
			ValueEdit* endAngleEdit;
			QLabel* angle;
			QLabel* angleDisplay;
			QLabel* length;
			QLabel* lengthDisplay;
			
			void update();
		
		private slots:
			void sltCenterChanged(double &x, double &y);
			void sltCenterSpecify();
			void sltRadiusChanged(double &value);
			void sltStartAngleChanged(double &value);
			void sltEndAngleChanged(double &value);
			
		};
	}
}

#endif // GUI__EDIT__ARCEDIT_H
