/***************************************************************************
 *                                                                         *
 *   gui/edit/circleedit.cpp                                               *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "circleedit.h"

#include <qmessagebox.h>

using namespace gui::edit;
using cad::CADCircle;

/* TRANSLATOR gui::edit::CircleEdit */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CircleEdit::CircleEdit(CADCircle* circle, QWidget* parent, const char* name):
	EntityEdit(parent, name)
{
	this->setFixedSize(350, 180);
	this->circle = circle;
	
	centerEdit = new CoordinateEdit(this);
	centerEdit->setGeometry(0, 0, centerEdit->width(), centerEdit->height());
	centerEdit->setTitle(tr("Center"));
	connect(centerEdit, SIGNAL(changed(double&,double&)), this,
		SLOT(sltCenterChanged(double&,double&)));
	connect(centerEdit, SIGNAL(specifyPoint()), this, SLOT(sltCenterSpecify()));
	
	radiusEdit = new ValueEdit(this);
	radiusEdit->setGeometry(150, 0, radiusEdit->width(), radiusEdit->height());
	radiusEdit->setTitle(tr("Radius:"));
	connect(radiusEdit, SIGNAL(valueChanged(double&)), this, 
		SLOT(sltRadiusChanged(double&)));

	diameter = new QLabel(this);
	diameter->setGeometry(150, 30, 105, 20);
	diameter->setText(tr("Diameter:"));
	diameterDisplay = new QLabel(this);
	diameterDisplay->setGeometry(260, 30, 90, 20);
	diameterDisplay->setAlignment(AlignRight);
	perimeter = new QLabel(this);
	perimeter->setGeometry(150, 50, 105, 20);
	perimeter->setText(tr("Perimeter:"));
	perimeterDisplay = new QLabel(this);
	perimeterDisplay->setGeometry(260, 50, 90, 20);
	perimeterDisplay->setAlignment(AlignRight);
	area = new QLabel(this);
	area->setGeometry(150, 70, 105, 20);
	area->setText(tr("Area:"));
	areaDisplay = new QLabel(this);
	areaDisplay->setGeometry(260, 70, 90, 20);
	areaDisplay->setAlignment(AlignRight);

	update();
}

CircleEdit::~CircleEdit()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the edited entity */
CADEntity* CircleEdit::getEntity() throw (Exception)
{
	circle->setCenterX(centerEdit->getX());
	circle->setCenterY(centerEdit->getY());
	circle->setRadius(radiusEdit->getValue());
	return circle;
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void CircleEdit::update()
{
	centerEdit->setCoordinate(circle->getCenterX(), circle->getCenterY());
	radiusEdit->setValue(circle->getRadius());
	QString text;
	text.sprintf("%1.4f", circle->getDiameter());
	diameterDisplay->setText(text);
	text.sprintf("%1.4f", circle->getPerimeter());
	perimeterDisplay->setText(text);
	text.sprintf("%1.4f", circle->getArea());
	areaDisplay->setText(text);
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void CircleEdit::sltCenterChanged(double &x, double &y)
{
	circle->setCenter(x, y);
	update();
}

void CircleEdit::sltCenterSpecify()
{
	emit specify();
}

void CircleEdit::sltRadiusChanged(double &value)
{
	circle->setRadius(value);
	update();
}

// EOF
