/***************************************************************************
 *                                                                         *
 *   gui/edit/coordinateedit.cpp                                           *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "coordinateedit.h"

#include <qmessagebox.h>

using gui::edit::CoordinateEdit;

/* TRANSLATOR gui::edit::CoordinateEdit */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CoordinateEdit::CoordinateEdit(QWidget* parent, const char* name) :
	QGroupBox(parent, name)
{
	resize(140, 130);
	
	specify = new QPushButton(this);
	specify->setGeometry(10, 20, 120, 30);
	specify->setText(tr("> Specify"));
	connect(specify, SIGNAL(clicked()), this, SLOT(sltSpecify()));
	x = new QLabel(this);
	x->setGeometry(10, 60, 20, 25);
	x->setText("X:");
	xEdit = new QLineEdit(this);
	xEdit->setGeometry(40, 60, 90, 25);
	xEdit->setAlignment(AlignRight);
	connect(xEdit, SIGNAL(lostFocus()), this, SLOT(sltXEnter()));
	y = new QLabel(this);
	y->setGeometry(10, 90, 20, 25);
	y->setText("Y:");
	yEdit = new QLineEdit(this);
	yEdit->setGeometry(40, 90, 90, 25);
	yEdit->setAlignment(AlignRight);
	connect(yEdit, SIGNAL(lostFocus()), this, SLOT(sltYEnter()));
}

CoordinateEdit::~CoordinateEdit()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/
			
double CoordinateEdit::getX() throw (Exception)
{
	bool ok;
	double x = xEdit->text().toDouble(&ok);
	if (!ok)
		throw Exception(tr("The value for %1 is invalid.").arg(this->title()));
	xValue = x;
	return xValue;
}

double CoordinateEdit::getY() throw (Exception)
{
	bool ok;
	double y = yEdit->text().toDouble(&ok);
	if (!ok)
		throw Exception(tr("The value for %1 is invalid.").arg(this->title()));
	yValue = y;
	return yValue;
}

void CoordinateEdit::setCoordinate(double x, double y)
{
	xValue = x;
	yValue = y;
	update();
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void CoordinateEdit::update()
{
	QString text;
	text.sprintf("%1.4f", xValue);
	xEdit->setText(text);
	text.sprintf("%1.4f", yValue);
	yEdit->setText(text);
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void CoordinateEdit::sltSpecify()
{
	emit specifyPoint();
}

void CoordinateEdit::sltXEnter()
{
	try
	{
		getX();
		update();
		emit changed(xValue, yValue);
	}
	catch (Exception e)
	{
	}
}

void CoordinateEdit::sltYEnter()
{
	try
	{
		getY();
		update();
		emit changed(xValue, yValue);
	}
	catch (Exception e)
	{
	}
}

// EOF
