/***************************************************************************
 *                                                                         *
 *   gui/edit/ellipseedit.cpp                                              *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "ellipseedit.h"

#include <qmessagebox.h>

using namespace gui::edit;
using cad::CADEllipse;

/* TRANSLATOR gui::edit::EllipseEdit */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

EllipseEdit::EllipseEdit(CADEllipse* ellipse, QWidget* parent, const char* name):
	EntityEdit(parent, name)
{
	this->setFixedSize(380, 200);
	this->ellipse = ellipse;
	
	centerEdit = new CoordinateEdit(this);
	centerEdit->setGeometry(0, 0, centerEdit->width(), centerEdit->height());
	centerEdit->setTitle(tr("Center"));
	connect(centerEdit, SIGNAL(changed(double&,double&)), this,
		SLOT(sltCenterChanged(double&,double&)));
	connect(centerEdit, SIGNAL(specifyPoint()), this, SLOT(sltCenterSpecify()));
	majorAxisEdit = new ValueEdit(this);
	majorAxisEdit->setGeometry(180, 0, majorAxisEdit->width(), 
		majorAxisEdit->height());
	majorAxisEdit->setTitle(tr("Major Axis:"));
	connect(majorAxisEdit, SIGNAL(valueChanged(double&)), this, 
		SLOT(sltMajorAxisChanged(double&)));
	minorAxisEdit = new ValueEdit(this);
	minorAxisEdit->setGeometry(180, 30, minorAxisEdit->width(), 
		minorAxisEdit->height());
	minorAxisEdit->setTitle(tr("Minor Axis:"));
	connect(minorAxisEdit, SIGNAL(valueChanged(double&)), this,
		SLOT(sltMinorAxisChanged(double&)));
	startAngleEdit = new ValueEdit(this);
	startAngleEdit->setGeometry(180, 60, startAngleEdit->width(), 
		startAngleEdit->height());
	startAngleEdit->setTitle(tr("Start Angle:"));
	connect(startAngleEdit, SIGNAL(valueChanged(double&)), this,
		SLOT(sltStartAngleChanged(double&)));
	endAngleEdit = new ValueEdit(this);
	endAngleEdit->setGeometry(180, 90, endAngleEdit->width(), 
		endAngleEdit->height());
	endAngleEdit->setTitle(tr("End Angle:"));
	connect(endAngleEdit, SIGNAL(valueChanged(double&)), this,
		SLOT(sltEndAngleChanged(double&)));
	
	axisRatio = new QLabel(this);
	axisRatio->setGeometry(180, 120, 105, 20);
	axisRatio->setText(tr("Axis Ratio:"));
	axisRatioDisplay = new QLabel(this);
	axisRatioDisplay->setGeometry(290, 120, 90, 20);
	axisRatioDisplay->setAlignment(AlignRight);
	majorAxisVectorX = new QLabel(this);
	majorAxisVectorX->setGeometry(0, 140, 95, 20);
	majorAxisVectorX->setText(tr("Major Vector X:"));
	majorAxisVectorXDisplay = new QLabel(this);
	majorAxisVectorXDisplay->setGeometry(100, 140, 75, 20);
	majorAxisVectorXDisplay->setAlignment(AlignRight);
	majorAxisVectorY = new QLabel(this);
	majorAxisVectorY->setGeometry(0, 160, 95, 20);
	majorAxisVectorY->setText(tr("Major Vector Y:"));
	majorAxisVectorYDisplay = new QLabel(this);
	majorAxisVectorYDisplay->setGeometry(100, 160, 75, 20);
	majorAxisVectorYDisplay->setAlignment(AlignRight);
	minorAxisVectorX = new QLabel(this);
	minorAxisVectorX->setGeometry(180, 140, 105, 20);
	minorAxisVectorX->setText(tr("Minor Vector X:"));
	minorAxisVectorXDisplay = new QLabel(this);
	minorAxisVectorXDisplay->setGeometry(290, 140, 90, 20);
	minorAxisVectorXDisplay->setAlignment(AlignRight);
	minorAxisVectorY = new QLabel(this);
	minorAxisVectorY->setGeometry(180, 160, 105, 20);
	minorAxisVectorY->setText(tr("Minor Vector Y:"));
	minorAxisVectorYDisplay = new QLabel(this);
	minorAxisVectorYDisplay->setGeometry(290, 160, 90, 20);
	minorAxisVectorYDisplay->setAlignment(AlignRight);
	
	update();
}

EllipseEdit::~EllipseEdit()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the edited entity */
CADEntity* EllipseEdit::getEntity() throw (Exception)
{
	ellipse->setCenterX(centerEdit->getX());
	ellipse->setCenterY(centerEdit->getY());
	ellipse->setMajorAxis(majorAxisEdit->getValue());
	ellipse->setMinorAxis(minorAxisEdit->getValue());
	ellipse->setStartAngle(startAngleEdit->getValue());
	ellipse->setEndAngle(endAngleEdit->getValue());
	return ellipse;
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void EllipseEdit::update()
{
	centerEdit->setCoordinate(ellipse->getCenterX(), ellipse->getCenterY());
	majorAxisEdit->setValue(ellipse->getMajorAxis());
	minorAxisEdit->setValue(ellipse->getMinorAxis());
	startAngleEdit->setValue(ellipse->getStartAngle());
	endAngleEdit->setValue(ellipse->getEndAngle());
	QString text;
	text.sprintf("%1.4f", ellipse->getAxisRatio());
	axisRatioDisplay->setText(text);
	text.sprintf("%1.4f", ellipse->getMajorAxisVectorX());
	majorAxisVectorXDisplay->setText(text);
	text.sprintf("%1.4f", ellipse->getMajorAxisVectorY());
	majorAxisVectorYDisplay->setText(text);
	text.sprintf("%1.4f", ellipse->getMinorAxisVectorX());
	minorAxisVectorXDisplay->setText(text);
	text.sprintf("%1.4f", ellipse->getMinorAxisVectorY());
	minorAxisVectorYDisplay->setText(text);
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void EllipseEdit::sltCenterChanged(double &x, double &y)
{
	ellipse->setCenter(x, y);
	update();
}

void EllipseEdit::sltCenterSpecify()
{
	emit specify();
}

void EllipseEdit::sltMajorAxisChanged(double &value)
{
	ellipse->setMajorAxis(value);
	update();
}

void EllipseEdit::sltMinorAxisChanged(double &value)
{
	ellipse->setMinorAxis(value);
	update();
}

void EllipseEdit::sltStartAngleChanged(double &value)
{
	ellipse->setStartAngle(value);
	update();
}

void EllipseEdit::sltEndAngleChanged(double &value)
{
	ellipse->setEndAngle(value);
	update();
}

// EOF
