/***************************************************************************
 *                                                                         *
 *   gui/edit/ellipseedit.h                                                *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GUI__EDIT__ELLIPSEEDIT_H
#define GUI__EDIT__ELLIPSEEDIT_H

#include "entityedit.h"
#include "coordinateedit.h"
#include "valueedit.h"
#include "../../cad/cadellipse.h"

#include <qwidget.h>

namespace gui
{
	namespace edit
	{
		using cad::CADEllipse;
		
		/**
		 * EllipseEdit is a widget for editing ellipses
		 * @author Christoph Permes
		 */
		class EllipseEdit : public EntityEdit
		{
		Q_OBJECT
		public:
			
			EllipseEdit(CADEllipse* ellipse, QWidget* parent = 0, 
				const char* name = 0);
			~EllipseEdit();
			
			/** @return the edited entity */
			virtual CADEntity* getEntity() throw (Exception);
			
		private:
			CADEllipse* ellipse;
			CoordinateEdit* centerEdit;
			ValueEdit* majorAxisEdit;
			ValueEdit* minorAxisEdit;
			ValueEdit* startAngleEdit;
			ValueEdit* endAngleEdit;
			QLabel* axisRatio;
			QLabel* axisRatioDisplay;
			QLabel* majorAxisVectorX;
			QLabel* majorAxisVectorY;
			QLabel* minorAxisVectorX;
			QLabel* minorAxisVectorY;
			QLabel* majorAxisVectorXDisplay;
			QLabel* majorAxisVectorYDisplay;
			QLabel* minorAxisVectorXDisplay;
			QLabel* minorAxisVectorYDisplay;
			
			void update();
		
		private slots:
			void sltCenterChanged(double &x, double &y);
			void sltCenterSpecify();
			void sltMajorAxisChanged(double &value);
			void sltMinorAxisChanged(double &value);
			void sltStartAngleChanged(double &value);
			void sltEndAngleChanged(double &value);
		
		};
	}
}

#endif // GUI__EDIT__ELLIPSEEDIT_H
