/***************************************************************************
 *                                                                         *
 *   gui/edit/lineedit.cpp                                                 *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "lineedit.h"

#include <qmessagebox.h>
#include <qheader.h>

using namespace gui::edit;
using cad::CADLine;

/* TRANSLATOR gui::edit::LineEdit */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

LineEdit::LineEdit(CADLine* line, QWidget* parent, const char* name):
	EntityEdit(parent, name)
{
	this->resize(290, 180);
	this->line = line;
	startEdit = new CoordinateEdit(this);
	startEdit->setGeometry(0, 0, startEdit->width(), startEdit->height());
	startEdit->setTitle(tr("Startpoint"));
	connect(startEdit, SIGNAL(changed(double&,double&)), this, 
		SLOT(sltStartChanged(double&,double&)));
	connect(startEdit, SIGNAL(specifyPoint()), this, SLOT(sltStartSpecify()));
	endEdit = new CoordinateEdit(this);
	endEdit->setGeometry(150, 0, endEdit->width(), endEdit->height());
	endEdit->setTitle(tr("Endpoint"));
	connect(endEdit, SIGNAL(changed(double&,double&)), this, 
		SLOT(sltEndChanged(double&,double&)));
	connect(endEdit, SIGNAL(specifyPoint()), this, SLOT(sltEndSpecify()));
	
	deltaX = new QLabel(this);
	deltaX->setGeometry(0, 140, 70, 20);
	deltaX->setText(tr("Delta X:"));
	deltaXDisplay = new QLabel(this);
	deltaXDisplay->setGeometry(70, 140, 70, 20);
	deltaXDisplay->setAlignment(AlignRight);
	deltaY = new QLabel(this);
	deltaY->setGeometry(0, 160, 70, 20);
	deltaY->setText(tr("Delta Y:"));
	deltaYDisplay = new QLabel(this);
	deltaYDisplay->setGeometry(70, 160, 70, 20);
	deltaYDisplay->setAlignment(AlignRight);
	length = new QLabel(this);
	length->setGeometry(150, 140, 70, 20);
	length->setText(tr("Length:"));
	lengthDisplay = new QLabel(this);
	lengthDisplay->setGeometry(220, 140, 70, 20);
	lengthDisplay->setAlignment(AlignRight);
	angle = new QLabel(this);
	angle->setGeometry(150, 160, 70, 20);
	angle->setText(tr("Angle:"));
	angleDisplay = new QLabel(this);
	angleDisplay->setGeometry(220, 160, 70, 20);
	angleDisplay->setAlignment(AlignRight);
	
	update();
}

LineEdit::~LineEdit()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the edited entity */
CADEntity* LineEdit::getEntity() throw (Exception)
{
	line->setStartX(startEdit->getX());
	line->setStartY(startEdit->getY());
	line->setEndX(endEdit->getX());
	line->setEndY(endEdit->getY());
	return line;
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void LineEdit::update()
{
	startEdit->setCoordinate(line->getStartX(), line->getStartY());
	endEdit->setCoordinate(line->getEndX(), line->getEndY());
	QString text;
	text.sprintf("%1.4f", line->getDeltaX());
	deltaXDisplay->setText(text);
	text.sprintf("%1.4f", line->getDeltaY());
	deltaYDisplay->setText(text);
	text.sprintf("%1.4f", line->getLength());
	lengthDisplay->setText(text);
	text.sprintf("%1.4f", line->getAngle());
	angleDisplay->setText(text);
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void LineEdit::sltStartChanged(double &x, double &y)
{
	line->setStart(x, y);
	update();
}

void LineEdit::sltStartSpecify()
{
	emit specify();
}

void LineEdit::sltEndChanged(double &x, double &y)
{
	line->setEnd(x, y);
	update();
}

void LineEdit::sltEndSpecify()
{
	emit specify();
}

// EOF
