/***************************************************************************
 *                                                                         *
 *   gui/edit/pointedit.cpp                                                *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "pointedit.h"

#include <qmessagebox.h>

using namespace gui::edit;
using cad::CADPoint;

/* TRANSLATOR gui::edit::PointEdit */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

PointEdit::PointEdit(CADPoint* point, QWidget* parent, const char* name):
	EntityEdit(parent, name)
{
	this->point = point;
	pointEdit = new CoordinateEdit(this);
	pointEdit->setTitle(tr("Point"));
	connect(pointEdit, SIGNAL(changed(double&,double&)), this,
		SLOT(sltChanged(double&,double&)));
	connect(pointEdit, SIGNAL(specifyPoint()), this, SLOT(sltPointSpecify()));
	this->resize(pointEdit->width(), pointEdit->height());
	
	update();
}

PointEdit::~PointEdit()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the edited entity */
CADEntity* PointEdit::getEntity() throw (Exception)
{
	point->setX(pointEdit->getX());
	point->setY(pointEdit->getY());
	return point;
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void PointEdit::update()
{
	pointEdit->setCoordinate(point->getX(), point->getY());
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void PointEdit::sltChanged(double &x, double &y)
{
	point->set(x, y);
	update();
}

void PointEdit::sltPointSpecify()
{
	emit specify();
}

// EOF
