/***************************************************************************
 *                                                                         *
 *   gui/edit/propertiesedit.h                                             *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GUI__EDIT__PROPERTIESEDIT_H
#define GUI__EDIT__PROPERTIESEDIT_H

#include "../../cad/cadpen.h"
#include "../../util/exception.h"

#include <qgroupbox.h>
#include <qpushbutton.h>
#include <qwidget.h>
#include <qlabel.h>
#include <qlineedit.h>

namespace gui
{
	namespace edit
	{
		using cad::CADPen;
		using util::Exception;
		
		/**
		 * PropertiesEdit is a widget for editing pen and layer settings
		 * @author Christoph Permes
		 */
		class PropertiesEdit : public QGroupBox
		{
		Q_OBJECT
		public:
			/**
				* Create a PropertiesEdit which edits the given properties
				*/
			PropertiesEdit(CADPen pen, QString layer, QWidget* parent = 0, 
				const char* name = 0);
			/** Destructor */
			~PropertiesEdit();
			
			/** @return the pen */
			CADPen getPen() throw (Exception);
			/** @return the layer */
			QString getLayer() const;
			
		private:
			CADPen pen;
			QString layer;
			QPushButton* color;
			QWidget* colorDisplay;
			QLabel* colorName;
			QPushButton* layerChange;
			QLabel* layerName;
			QPushButton* linetype;
			QLabel* linetypeName;
			QLabel* factor;
			QLineEdit* linetypeFactor;
			
			/** updates the display */
			void update();
		
		private slots:
			void sltColor();
			void sltLayer();
			void sltLinetype();
			void sltLinetypeFactor();

		};
	}
}

#endif // GUI__EDIT__PROPERTIESEDIT_H
