/***************************************************************************
 *                                                                         *
 *   gui/edit/rayedit.cpp                                                  *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "rayedit.h"

#include <qmessagebox.h>

using namespace gui::edit;

/* TRANSLATOR gui::edit::RayEdit */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

RayEdit::RayEdit(CADRay* ray, QWidget* parent, const char* name):
	EntityEdit(parent, name)
{
	this->resize(290, 180);
	this->ray = ray;
	startEdit = new CoordinateEdit(this);
	startEdit->setGeometry(0, 0, startEdit->width(), startEdit->height());
	startEdit->setTitle(tr("Startpoint"));
	connect(startEdit, SIGNAL(changed(double&,double&)), this, 
		SLOT(sltStartChanged(double&,double&)));
	connect(startEdit, SIGNAL(specifyPoint()), this, SLOT(sltStartSpecify()));
	secondEdit = new CoordinateEdit(this);
	secondEdit->setGeometry(150, 0, secondEdit->width(), secondEdit->height());
	secondEdit->setTitle(tr("Second Point"));
	connect(secondEdit, SIGNAL(changed(double&,double&)), this, 
		SLOT(sltSecondChanged(double&,double&)));
	connect(secondEdit, SIGNAL(specifyPoint()), this, SLOT(sltSecondSpecify()));
		
	directionX = new QLabel(this);
	directionX->setGeometry(0, 140, 70, 20);
	directionX->setText(tr("Direction X:"));
	directionXDisplay = new QLabel(this);
	directionXDisplay->setGeometry(70, 140, 70, 20);
	directionXDisplay->setAlignment(AlignRight);
	directionY = new QLabel(this);
	directionY->setGeometry(0, 160, 70, 20);
	directionY->setText(tr("Direction Y:"));
	directionYDisplay = new QLabel(this);
	directionYDisplay->setGeometry(70, 160, 70, 20);
	directionYDisplay->setAlignment(AlignRight);
	
	update();
}

RayEdit::~RayEdit()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the edited entity */
CADEntity* RayEdit::getEntity() throw (Exception)
{
	ray->setStartX(startEdit->getX());
	ray->setStartY(startEdit->getY());
	ray->setSecondX(secondEdit->getX());
	ray->setSecondY(secondEdit->getY());
	return ray;
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void RayEdit::update()
{
	startEdit->setCoordinate(ray->getStartX(), ray->getStartY());
	secondEdit->setCoordinate(ray->getSecondX(), ray->getSecondY());
	QString text;
	text.sprintf("%1.4f", ray->getDirectionX());
	directionXDisplay->setText(text);
	text.sprintf("%1.4f", ray->getDirectionY());
	directionYDisplay->setText(text);
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void RayEdit::sltStartChanged(double &x, double &y)
{
	ray->setStart(x, y);
	update();	
}

void RayEdit::sltStartSpecify()
{
	emit specify();
}

void RayEdit::sltSecondChanged(double &x, double &y)
{
	ray->setSecond(x, y);
	update();	
}

void RayEdit::sltSecondSpecify()
{
	emit specify();
}

// EOF
