/***************************************************************************
 *                                                                         *
 *   gui/edit/valueedit.cpp                                                *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "valueedit.h"

#include <qmessagebox.h>

using gui::edit::ValueEdit;

/* TRANSLATOR gui::edit::ValueEdit */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/**
 * Constructor
 * Create a ValueEdit
 */
ValueEdit::ValueEdit(QWidget* parent, const char* name) : QWidget(parent, name)
{
	setFixedSize(200, 25);
	title = new QLabel(this);
	title->setGeometry(0, 0, 105, 25);
	valueEdit = new QLineEdit(this);
	valueEdit->setGeometry(110, 0, 90, 25);
	valueEdit->setAlignment(AlignRight);
	connect(valueEdit, SIGNAL(lostFocus()), this, SLOT(sltValueEnter()));
}

/** Destructor */
ValueEdit::~ValueEdit()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the entered value */
double ValueEdit::getValue() throw (Exception)
{
	bool ok;
	double value = valueEdit->text().toDouble(&ok);
	if (!ok)
		throw Exception(tr("The value for %1 is invalid.").arg(title->text()));
	this->setValue(value);
	return value;
}

/** set the initial value */
void ValueEdit::setValue(double value)
{
	this->value = value;
	QString text;
	text.sprintf("%1.4f", value);
	valueEdit->setText(text);
}

/** set the value description */
void ValueEdit::setTitle(QString title)
{
	this->title->setText(title);
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void ValueEdit::sltValueEnter()
{
	try
	{
		getValue();
		emit valueChanged(value);
	}
	catch (Exception e)
	{
	}
}

// EOF
