/***************************************************************************
 *                                                                         *
 *   gui/mainwindow.h                                                      *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GUI__MAINWINDOW_H
#define GUI__MAINWINDOW_H

#include <qmainwindow.h>
#include <qevent.h>
#include <qpopupmenu.h>
#include <qtoolbar.h>
#include <qaction.h>
#include <qlabel.h>
#include <qcombobox.h>

#include "../io/iointerface.h"
#include "../io/drawingmanager.h"
#include "widgets/commandwidget.h"

namespace gui
{
	using namespace cad;
	using namespace widgets;
	using io::DrawingManager;
	
	/**
	 * MainWindow is the main window of ConstructCAD
	 * @author Christoph Permes
	 */
	class MainWindow : public QMainWindow, public IOInterface
	{
	Q_OBJECT
	public:
		MainWindow(QWidget* parent = 0, char* name = 0);
		~MainWindow();
		
		virtual QString readInput() throw (Exception);
		virtual void print(QString s);
		virtual void printLine(QString s);
		virtual void draw(CADDrawing* drawing);
		virtual void updatePropertiesDisplay();
		virtual void quitApplication();

	protected:
		void resizeEvent(QResizeEvent* e);

	private:
		QPopupMenu* fileMenu;
		QPopupMenu* editMenu;
		QPopupMenu* toolsMenu;
		QPopupMenu* toolsDrawMenu;
		QPopupMenu* toolsModifyMenu;
		QPopupMenu* toolsSnapMenu;
		QPopupMenu* toolsDimensioningMenu;
		QPopupMenu* toolsZoomMenu;
		QPopupMenu* toolsToolboxesMenu;
		QPopupMenu* helpMenu;
		QLabel* status[1];
		QToolBar* standardToolBar;
		QToolBar* propertiesToolBar;
		QToolBar* drawToolBar;
		QToolBar* modifyToolBar;
		QToolBar* osnapToolBar;
		QToolBar* dimToolBar;
		QToolBar* zoomToolBar;
		QComboBox* layerSelection;
		QComboBox* linetypeSelection;
		
		QWidget* drawing;
		CommandWidget* commandWidget;
		DrawingManager* drawingManager;

		QAction* fileNewAction;
		QAction* fileOpenAction;
		QAction* fileCloseAction;
		QAction* fileSaveAction;
		QAction* fileSaveAsAction;
		QAction* filePlotAction;
		QAction* fileQuitAction;
		QAction* editUndoAction;
		QAction* editRedoAction;
		QAction* editCutAction;
		QAction* editCopyAction;
		QAction* editPasteAction;
		QAction* toolsToolboxesDrawAction;
		QAction* toolsToolboxesModifyAction;
		QAction* toolsToolboxesOSnapAction;
		QAction* toolsToolboxesDimAction;
		QAction* toolsToolboxesZoomAction;
		QAction* toolsOptionsAction;
		QAction* helpHelpAction;
		QAction* helpAboutAction;
		
		QAction* propertiesLayersAction;
		QAction* propertiesLayerChangeAction;
		QAction* propertiesColorAction;
		QAction* propertiesLinetypeAction;
		QAction* propertiesObjectAction;
		QAction* propertiesPropertiesAction;
		QAction* zoomInAction;
		QAction* zoomOutAction;
		QAction* zoomWindowAction;
		QAction* zoomAllAction;
		QAction* zoomPreviousAction;
		QAction* zoomScaleAction;
		QAction* zoomExtentAction;
		QAction* zoomCenterAction;
		
		QAction* drawLineAction;
		QAction* drawXLineAction;
		QAction* drawRayAction;
		QAction* drawPLineAction;
		QAction* drawMLineAction;
		QAction* drawArcAction;
		QAction* drawArcContinueAction;
		QAction* drawCircleAction;
		QAction* drawRingAction;
		QAction* drawEllipseAction;
		QAction* drawPolygonAction;
		QAction* drawRectangleAction;
		QAction* drawSolidAction;
		QAction* drawPointAction;
		QAction* drawBlockAction;
		QAction* drawBlockInsertAction;
		QAction* drawHatchAction;
		QAction* drawTextAction;
		QAction* drawTextSLAction;

		QAction* modifyMoveAction;
		QAction* modifyCopyAction;
		QAction* modifyOffsetAction;
		QAction* modifyMirrorAction;
		QAction* modifyArrayRectAction;
		QAction* modifyArrayPolarAction;
		QAction* modifyRotateAction;
		QAction* modifyStretchAction;
		QAction* modifyScaleAction;
		QAction* modifyLengthenAction;
		QAction* modifyTrimAction;
		QAction* modifyExtendAction;
		QAction* modifyBreakAction;
		QAction* modifyEditTextAction;
		QAction* modifyHatchEditAction;
		QAction* modifyChamferAction;
		QAction* modifyFilletAction;
		QAction* modifyExplodeAction;
		QAction* modifyEraseAction;
		
		QAction* snapFromPoint;
		QAction* snapEndpoint;
		QAction* snapMidpoint;
		QAction* snapIntersection;
		QAction* snapCenter;
		QAction* snapQuadrant;
		QAction* snapPerpendicular;
		QAction* snapTangent;
		QAction* snapNode;
		QAction* snapBasepoint;
		QAction* snapNearest;
		QAction* snapNon;
		QAction* snapObject;
		QAction* snapCalculator;
		
		QAction* dimLinear;
		QAction* dimAligned;
		QAction* dimRadius;
		QAction* dimDiameter;
		QAction* dimAngular;
		QAction* dimOrdinate;
		QAction* dimOrdinateX;
		QAction* dimOrdinateY;
		QAction* dimBaseline;
		QAction* dimContinue;
		QAction* dimCenter;
		QAction* dimLeader;
		QAction* dimTEdit;
		QAction* dimTERotate;
		QAction* dimTELeft;
		QAction* dimTEHome;
		QAction* dimTERight;
		QAction* dimStyle;
		QAction* dimEdit;
		
		void createMenu();
		void createFileMenu();
		void createEditMenu();
		void createToolsMenu();
		void createToolsDrawMenu();
		void createToolsModifyMenu();
		void createToolsOSnapMenu();
		void createToolsDimMenu();
		void createToolsZoomMenu();
		void createHelpMenu();

		void createStandardToolBar();
		void createPropertiesToolBar();
		void createDrawToolBar();
		void createModifyToolBar();
		void createOSnapToolBar();
		void createDimToolBar();
		void createZoomToolBar();

		void initializeStatusBar();

		void createActions();
		void createFileActions();
		void createEditActions();
		void createToolsActions();
		void createHelpActions();
		void createPropertiesActions();
		void createZoomActions();
		void createDrawActions();
		void createModifyActions();
		void createSnapActions();
		void createDimActions();

	public slots:
		void sltFileNew();
		void sltFileOpen();
		void sltFileClose();
		void sltFileSave();
		void sltFileSaveAs();
		void sltFilePlot();
		void sltFileQuit();
		
		void sltEditUndo();
		void sltEditRedo();
		void sltEditCut();
		void sltEditCopy();
		void sltEditPaste();
		
		void sltToolboxesDraw();
		void sltToolboxesModify();
		void sltToolboxesOSnap();
		void sltToolboxesDim();
		void sltToolboxesZoom();
		void sltToolsOptions();
		
		void sltHelpHelp();
		void sltHelpAbout();
		
		void sltPropertiesLayers();
		void sltPropertiesLayerChange(const QString& string);
		void sltPropertiesColor();
		void sltPropertiesLinetype();
		void sltPropertiesLinetypeChange(const QString& string);
		void sltPropertiesObject();
		void sltPropertiesProperties();
		
		void sltZoomIn();
		void sltZoomOut();
		void sltZoomWindow();
		void sltZoomAll();
		void sltZoomPrevious();
		void sltZoomScale();
		void sltZoomExtent();
		void sltZoomCenter();
		
		void sltDrawLine();
		void sltDrawXLine();
		void sltDrawRay();
		void sltDrawPLine();
		void sltDrawMLine();
		void sltDrawArc();
		void sltDrawArcContinue();
		void sltDrawCircle();
		void sltDrawRing();
		void sltDrawEllipse();
		void sltDrawPolygon();
		void sltDrawRectangle();
		void sltDrawSolid();
		void sltDrawPoint();
		void sltDrawBlock();
		void sltDrawBlockInsert();
		void sltDrawHatch();
		void sltDrawText();
		void sltDrawTextSL();
		
		void sltModifyMove();
		void sltModifyCopy();
		void sltModifyOffset();
		void sltModifyMirror();
		void sltModifyArrayRect();
		void sltModifyArrayPolar();
		void sltModifyRotate();
		void sltModifyStretch();
		void sltModifyScale();
		void sltModifyLengthen();
		void sltModifyTrim();
		void sltModifyExtend();
		void sltModifyBreak();
		void sltModifyEditText();
		void sltModifyHatchEdit();
		void sltModifyChamfer();
		void sltModifyFillet();
		void sltModifyExplode();
		void sltModifyErase();
		
		void sltSnapFromPoint();
		void sltSnapEndpoint();
		void sltSnapMidpoint();
		void sltSnapIntersection();
		void sltSnapCenter();
		void sltSnapQuadrant();
		void sltSnapPerpendicular();
		void sltSnapTangent();
		void sltSnapNode();
		void sltSnapBasepoint();
		void sltSnapNearest();
		void sltSnapNon();
		void sltSnapObject();
		void sltSnapCalculator();
		
		void sltDimLinear();
		void sltDimAligned();
		void sltDimRadius();
		void sltDimDiameter();
		void sltDimAngular();
		void sltDimOrdinate();
		void sltDimOrdinateX();
		void sltDimOrdinateY();
		void sltDimBaseline();
		void sltDimContinue();
		void sltDimCenter();
		void sltDimLeader();
		void sltDimTEdit();
		void sltDimTERotate();
		void sltDimTELeft();
		void sltDimTEHome();
		void sltDimTERight();
		void sltDimStyle();
		void sltDimEdit();
		
		void commandInput(QString& command);

	};
}

#endif // GUI__MAINWINDOW_H
