/***************************************************************************
 *                                                                         *
 *   gui/widgets/commandline.cpp                                           *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "commandline.h"

#include <qmessagebox.h>
#include <qapplication.h>
#include "../../io/drawingmanager.h"

using gui::widgets::CommandLine;
using cad::CADCoordinate;
using io::DrawingManager;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CommandLine::CommandLine(CommandHistory* history, QWidget* parent, char* name) : 
QLineEdit(parent, name)
{
	this->history = history;
	QFont font("Courier", 12);
	setFont(font);
	setMinimumHeight(20);
	setMaximumHeight(minimumHeight());
	setReadOnly(true);
}

CommandLine::~CommandLine()
{
	
}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

void CommandLine::print(QString s)
{
	currentText += s;
	printAll();
}

void CommandLine::clear()
{
	currentText = "";
	currentInput = "";
	printAll();
}

/***************************************************************************
 * Protected Methods                                                       *
 ***************************************************************************/

void CommandLine::keyPressEvent(QKeyEvent* e)
{
	int key = e->key();
	QString line, input;
	
	switch (key)
	{
	case Qt::Key_Enter:
	case Qt::Key_Return:
		if (currentInput == "")
		{
			currentInput = history->last();
			printAll();
		}
		history->add(currentInput);
		history->reset();
		line = currentText + currentInput;
		input = currentInput;
		clear();
		emit this->input(line, input);
		break;
	case Qt::Key_Backspace:
		currentInput = currentInput.left(currentInput.length()-1);
		printAll();
		break;
	case Qt::Key_Up:
		currentInput = history->previous();
		printAll();
		break;
	case Qt::Key_Down:
		currentInput = history->next();
		printAll();
		break;
	default:
		char character = e->ascii();
		bool accept = false;
		if ((character >= 'a') && (character <= 'z'))
			accept = true;
		if ((character >= 'A') && (character <= 'Z'))
			accept = true;
		if ((character >= '0') && (character <= '9'))
			accept = true;
		switch (character)
		{
		case ',':
		case '.':
		case '+':
		case '-':
		case '<':
		case '>':
		case '@':
		case ' ':
		case '\'':
			accept = true;	
		}
		if (accept)
		{
			currentInput += e->ascii();
			printAll();
		}
		break;
	}
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void CommandLine::printAll()
{
	setText(currentText + currentInput);
}

/*QString CommandLine::getInput()
{
	inputfinished = false;
	while (!inputfinished)
	{
		qApp->processEvents(500);
	}
	return currentInput;
}

CADCoordinate CommandLine::getCoordinateInput()
{
	inputfinished = false;
	while (!inputfinished)
	{
		qApp->processEvents(500);
	}
	return CADCoordinate();	
}*/

// EOF
