/***************************************************************************
 *                                                                         *
 *   gui/widgets/commandline.cpp                                           *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "commandwidget.h"

#include "../../io/drawingmanager.h"

using gui::widgets::CommandLine;
using gui::widgets::CommandWidget;
using namespace io;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CommandWidget::CommandWidget(CommandHistory* history, QWidget* parent, char* name) : 
QWidget(parent, name)
{
	this->setMinimumHeight(70);
	
	commandLine = new CommandLine(history, this);
	commandLine->setGeometry(0, height()-commandLine->height(), width(),
		commandLine->height());
	connect(commandLine, SIGNAL(input(QString&,QString&)), this,
		SLOT(appendLine(QString&,QString&)));
	this->history = new QTextEdit(this);
	this->history->setGeometry(0, 0, width(), height()-commandLine->height());
	this->history->setFont(QFont("Courier", 12));
	this->history->setReadOnly(true);
}

CommandWidget::~CommandWidget()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

CommandLine* CommandWidget::getCommandLine()
{
	return commandLine;
}

IOState CommandWidget::getIOState() const
{
	return state;
}

void CommandWidget::setIOState(IOState state)
{
	this->state = state;
	switch (state)
	{
	case IO_Ready:
		qDebug("setIOState(IO_Ready)");
		commandLine->clear();
		commandLine->print("Command: ");
		break;
	case IO_Cancel:
		break;
	case IO_String:
		break;
	case IO_Coordinate:
		break;
	}
}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

void CommandWidget::print(QString s)
{
	commandLine->print(s);
}

void CommandWidget::printLine(QString s)
{
	history->append(commandLine->text()+s);
	commandLine->clear();
}

/***************************************************************************
 * Protected Methods                                                       *
 ***************************************************************************/

void CommandWidget::resizeEvent(QResizeEvent* e)
{
	commandLine->setGeometry(0, height()-commandLine->height(), width(),
		commandLine->height());
	history->setGeometry(0, 0, width(), height()-commandLine->height());
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void CommandWidget::appendLine(QString& line, QString& input)
{
	history->append(line);
	emit this->input(input);
}
