/***************************************************************************
 *                                                                         *
 *   io/drawingmanager.cpp                                                 *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "drawingmanager.h"

#include "iointerface.h"
#include "../gui/dialogs/aboutdialog.h"
#include <qmessagebox.h>

#include "../gui/dialogs/layerdialog.h"
#include "../gui/dialogs/colordialog.h"
#include "../gui/dialogs/linetypedialog.h"
#include "../gui/dialogs/propertiesdialog.h"
#include "../cad/cadline.h"
#include "../cad/cadcircle.h"
#include "../cad/cadarc.h"
#include "../cad/cadellipse.h"
#include "../cad/cadpoint.h"
#include "../cad/cadxline.h"
#include "../cad/cadray.h"

using namespace io;
using namespace gui::dialogs;
using namespace cad;

DrawingManager* DrawingManager::instance = 0;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

// Private Constructor
DrawingManager::DrawingManager()
{
	drawing = new CADDrawing;
}

DrawingManager::~DrawingManager()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

DrawingManager* DrawingManager::getInstance()
{
	if (instance == 0)
	{
		instance = new DrawingManager();
	}
	return instance;
}

CADDrawing* DrawingManager::getDrawing() const
{
	return drawing;
}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

void DrawingManager::fileNew()
{
    QMessageBox::information(0, "TODO", "TODO: DrawingManager::fileNew()");
}

void DrawingManager::fileOpen()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::fileOpen()");
}

void DrawingManager::fileClose()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::fileClose()");
}

void DrawingManager::fileSave()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::fileSave()");
}

void DrawingManager::fileSaveAs()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::fileSaveAs()");
}

void DrawingManager::filePlot()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::filePlot()");
}

void DrawingManager::fileQuit()
{
//	QMessageBox::information(0, "TODO", "TODO: DrawingManager::fileQuit()");
//	parent->close();
}

void DrawingManager::editUndo()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::editUndo()");
}

void DrawingManager::editRedo()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::editRedo()");
}

void DrawingManager::editCut()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::editCut()");
}

void DrawingManager::editCopy()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::editCopy()");
}

void DrawingManager::editPaste()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::editPaste()");
}

void DrawingManager::helpHelp()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::helpHelp()");
}

void DrawingManager::helpAbout()
{
	AboutDialog about;
	about.exec();
}

void DrawingManager::propertiesLayers(IOInterface* iointerface)
{
	CADLayerList layers = drawing->getLayerList();
    LayerDialog layerDialog(layers);
    if (layerDialog.exec())
    {
    	drawing->updateLayerList(layerDialog.getLayerList(), layerDialog.getLayerRenamingManager());
		iointerface->updatePropertiesDisplay();
    }
}

void DrawingManager::propertiesLayersChange(const QString& string, IOInterface* iointerface)
{
	drawing->setActiveLayer(string);
	iointerface->updatePropertiesDisplay();
}

void DrawingManager::propertiesColor(IOInterface* iointerface)
{
	CADPen pen = drawing->getActivePen();
	ColorDialog dlg(pen.getColor(), drawing->getActiveLayer().getName());
	if (dlg.exec())
	{
		pen.setColor(dlg.getColor());
		drawing->setActivePen(pen);
		iointerface->updatePropertiesDisplay();
	}
}

void DrawingManager::propertiesLinetype(IOInterface* iointerface)
{
	CADPen pen = drawing->getActivePen();
	LinetypeDialog dlg(drawing->getLinetypeList(), true);
	dlg.setLinetype(pen.getLinetype());
	if (dlg.exec())
	{
		pen.setLinetype(dlg.getLinetype());
		drawing->setActivePen(pen);
		drawing->updateLinetypeList(dlg.getLinetypeList());
		iointerface->updatePropertiesDisplay();
	}
}

void DrawingManager::propertiesLinetypeChange(const QString& string, IOInterface* iointerface)
{
	CADPen pen = drawing->getActivePen();
	pen.setLinetype(string);
	drawing->setActivePen(pen);
	iointerface->updatePropertiesDisplay();
}

void DrawingManager::propertiesObject(IOInterface* iointerface)
{
	PropertiesDialog p(0);
	if (p.exec())
	{
//		drawing->setObjectProperties(*(p.getObject()));
		iointerface->updatePropertiesDisplay();
	}
	qDebug("DrawingManager::propertiesObject end");
}
	
void DrawingManager::drawLine()
{
//	QMessageBox::information(parent, "TODO", "TODO: DrawingManager::drawLine()");
	CADLine* line = new CADLine("0");
	PropertiesDialog p(line);
	p.exec();
}

void DrawingManager::drawXLine()
{
//	QMessageBox::information(parent, "TODO", "TODO: DrawingManager::drawXLine()");
	CADXLine* xline = new CADXLine("0");
	PropertiesDialog p(xline);
	p.exec();
}

void DrawingManager::drawRay()
{
//	QMessageBox::information(parent, "TODO", "TODO: DrawingManager::drawRay()");
	CADRay* ray = new CADRay("0");
	PropertiesDialog p(ray);
	p.exec();
}

void DrawingManager::drawPLine()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::drawPLine()");
}

void DrawingManager::drawMLine()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::drawMLine()");
}

void DrawingManager::drawArc()
{
//	QMessageBox::information(parent, "TODO", "TODO: DrawingManager::drawArc()");
	CADArc* arc = new CADArc("0");
	PropertiesDialog p(arc);
	p.exec();
}

void DrawingManager::drawArcContinue()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::drawArcContinue()");
}

void DrawingManager::drawCircle()
{
//	QMessageBox::information(parent, "TODO", "TODO: DrawingManager::drawCircle()");
	CADCircle* circle = new CADCircle("0");
	PropertiesDialog p(circle);
	p.exec();
}

void DrawingManager::drawRing()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::drawRing()");
}

void DrawingManager::drawEllipse()
{
//	QMessageBox::information(parent, "TODO", "TODO: DrawingManager::drawEllipse()");
	CADEllipse* ellipse = new CADEllipse("0", 100.0, 100.0, 2.0, 2.0, 0.5, 0.0, 360.0);
	PropertiesDialog p(ellipse);
	p.exec();
}

void DrawingManager::drawPolygon()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::drawPolygon()");
}

void DrawingManager::drawRectangle()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::drawRectangle()");
}

void DrawingManager::drawSolid()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::drawSolid()");
}

void DrawingManager::drawPoint()
{
//	QMessageBox::information(parent, "TODO", "TODO: DrawingManager::drawPoint()");
	CADPoint* point = new CADPoint("0");
	PropertiesDialog p(point);
	p.exec();
}

void DrawingManager::drawBlock()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::drawBlock()");
}

void DrawingManager::drawBlockInsert()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::drawBlockInsert()");
}

void DrawingManager::drawHatch()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::drawHatch()");
}

void DrawingManager::drawText()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::drawText()");
}
void DrawingManager::drawTextSL()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::drawPLine()");
}

void DrawingManager::modifyMove()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyMove()");
}

void DrawingManager::modifyCopy()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyCopy()");
}

void DrawingManager::modifyOffset()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyOffset()");
}

void DrawingManager::modifyMirror()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyMirror()");
}

void DrawingManager::modifyArrayRect()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyArrayRect()");
}

void DrawingManager::modifyArrayPolar()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyArrayPolar()");
}

void DrawingManager::modifyRotate()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyRotate()");
}

void DrawingManager::modifyStretch()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyStretch()");
}

void DrawingManager::modifyScale()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyScale()");
}

void DrawingManager::modifyLengthen()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyLengthen()");
}

void DrawingManager::modifyTrim()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyTrim()");
}

void DrawingManager::modifyExtend()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyExtend()");
}

void DrawingManager::modifyBreak()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyBreak()");
}

void DrawingManager::modifyEditText()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyEditText()");
}

void DrawingManager::modifyHatchEdit()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyHatchEdit()");
}

void DrawingManager::modifyChamfer()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyChamfer()");
}

void DrawingManager::modifyFillet()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyFillet()");
}

void DrawingManager::modifyExplode()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyExplode()");
}

void DrawingManager::modifyErase()
{
	QMessageBox::information(0, "TODO", "TODO: DrawingManager::modifyErase()");
}

// EOF
