/***************************************************************************
 *                                                                         *
 *   io/drawingmanager.h                                                   *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef IO__DRAWINGMANAGER_H
#define IO__DRAWINGMANAGER_H

#include <qstring.h>
#include <qwidget.h>
#include <qcombobox.h>
#include <qaction.h>

#include "../cad/caddrawing.h"
#include "commandhistory.h"
#include "../util/exception.h"

using namespace cad;
using namespace util;

namespace io
{
	// forward declaration
	class IOInterface;

	/**
	 * DrawingManager is an interface between the GUI and the drawing
	 * @author Christoph Permes
	 */
	class DrawingManager
	{
	public:
		virtual ~DrawingManager();
	
		static DrawingManager* getInstance();
		
		CADDrawing* getDrawing() const;
		
		void fileNew();
		void fileOpen();
		void fileClose();
		void fileSave();
		void fileSaveAs();
		void filePlot();
		void fileQuit();
		void editUndo();
		void editRedo();
		void editCut();
		void editCopy();
		void editPaste();
		void helpHelp();
		void helpAbout();
	
		void propertiesLayers(IOInterface* iointerface);
		void propertiesLayersChange(const QString& string, IOInterface* iointerface);
		void propertiesColor(IOInterface* iointerface);
		void propertiesLinetype(IOInterface* iointerface);
		void propertiesLinetypeChange(const QString& string, IOInterface* iointerface);
		void propertiesObject(IOInterface* iointerface);
	
		void drawLine();
		void drawXLine();
		void drawRay();
		void drawPLine();
		void drawMLine();
		void drawArc();
		void drawArcContinue();
		void drawCircle();
		void drawRing();
		void drawEllipse();
		void drawPolygon();
		void drawRectangle();
		void drawSolid();
		void drawPoint();
		void drawBlock();
		void drawBlockInsert();
		void drawHatch();
		void drawText();
		void drawTextSL();
	
		void modifyMove();
		void modifyCopy();
		void modifyOffset();
		void modifyMirror();
		void modifyArrayRect();
		void modifyArrayPolar();
		void modifyRotate();
		void modifyStretch();
		void modifyScale();
		void modifyLengthen();
		void modifyTrim();
		void modifyExtend();
		void modifyBreak();
		void modifyEditText();
		void modifyHatchEdit();
		void modifyChamfer();
		void modifyFillet();
		void modifyExplode();
		void modifyErase();
		
	private:
		DrawingManager();
	
		static DrawingManager* instance;
		CADDrawing* drawing;
		
	};
	
}

#endif // IO__DRAWINGMANAGER_H
