/***************************************************************************
 *                                                                         *
 *   io/iointerface.cpp                                                    *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "iointerface.h"

using namespace io;
using namespace cad;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/** Constructor */
IOInterface::IOInterface()
{
	this->drawingManager = DrawingManager::getInstance();
	commandHistory = new CommandHistory;
}

/** Destructor */
IOInterface::~IOInterface()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the drawing manager */
DrawingManager* IOInterface::getDrawingManager() const
{
	return drawingManager;
}

/** @return the command history */
CommandHistory* IOInterface::getCommandHistory() const
{
	return commandHistory;
}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

void IOInterface::runCommand(QString command, QWidget* widgetParent)
{
	command = command.upper();
	if (command == "NEW") drawingManager->fileNew();
	else if (command == "OPEN") drawingManager->fileOpen();
	else if (command == "SAVE") drawingManager->fileSave();
	else if (command == "SAVEAS") drawingManager->fileSaveAs();
	else if (command == "PLOT") drawingManager->filePlot();
	else if (command == "QUIT") quitApplication();
	else if (command == "UNDO") drawingManager->editUndo();
	else if (command == "REDO") drawingManager->editRedo();
	else if ((command == "LAYER") || (command == "LA")) drawingManager->propertiesLayers(this);
	else if ((command == "LINE") || (command == "L")) drawingManager->drawLine();
	else if (command == "XLINE") drawingManager->drawXLine();
	else if (command == "RAY") drawingManager->drawRay();
	else if (command == "PLINE") drawingManager->drawPLine();
	else if ((command == "ARC") || (command == "A")) drawingManager->drawArc();
	else if ((command == "CIRCLE") || (command == "C")) drawingManager->drawCircle();
	else if (command == "DONUT") drawingManager->drawRing();
	else if (command == "ELLIPSE") drawingManager->drawEllipse();
	else if (command == "POLYGON") drawingManager->drawPolygon();
	else if ((command == "RECTANG") || (command == "REC")) drawingManager->drawRectangle();
	else if (command == "SOLID") drawingManager->drawSolid();
	else if (command == "POINT") drawingManager->drawPoint();
	else if (command == "BLOCK") drawingManager->drawBlock();
	else if ((command == "INSERT") || (command == "DDINSERT")) drawingManager->drawBlockInsert();
	else if (command == "HATCH") drawingManager->drawHatch();
	else if (command == "MTEXT") drawingManager->drawText();
	else if (command == "TEXT") drawingManager->drawTextSL();
	else if ((command == "MOVE") || (command == "M")) drawingManager->modifyMove();
	else if ((command == "COPY") || (command == "CP")) drawingManager->modifyCopy();
	else if (command == "OFFSET") drawingManager->modifyOffset();
	else if (command == "MIRROR") drawingManager->modifyMirror();
	else if (command == "ARRAY") drawingManager->modifyArrayRect();
	else if (command == "ROTATE") drawingManager->modifyRotate();
	else if (command == "STRETCH") drawingManager->modifyStretch();
	else if (command == "SCALE") drawingManager->modifyScale();
	else if (command == "LENGTHEN") drawingManager->modifyLengthen();
	else if (command == "TRIM") drawingManager->modifyTrim();
	else if (command == "EXTEND") drawingManager->modifyExtend();
	else if (command == "BREAK") drawingManager->modifyBreak();
	else if (command == "DDEDIT") drawingManager->modifyEditText();
	else if (command == "HATCHEDIT") drawingManager->modifyHatchEdit();
	else if (command == "CHAMFER") drawingManager->modifyChamfer();
	else if (command == "FILLET") drawingManager->modifyFillet();
	else if (command == "EXPLODE") drawingManager->modifyExplode();
	else if ((command == "ERASE") || (command == "E")) drawingManager->modifyErase();
	else printLine("Command not found.");
	commandHistory->add(command);
}

// EOF
