/***************************************************************************
 *                                                                         *
 *   io/iointerface.h                                                      *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef IO__IOINTERFACE_H
#define IO__IOINTERFACE_H

#include <qwidget.h>

#include "drawingmanager.h"
#include "commandhistory.h"
#include "../util/exception.h"

using namespace cad;
using namespace util;

namespace io
{
	/**
	 * IOInterface is an interface between the GUI and the DrawingManager
	 * @author Christoph Permes
	 */
	class IOInterface
	{
	public:
		/** Constructor */
		IOInterface();
		/** Destructor */
		virtual ~IOInterface();
	
		/** @return the drawing manager */
		DrawingManager* getDrawingManager() const;
		/** @return the command history */
		CommandHistory* getCommandHistory() const;
		
		void runCommand(QString command, QWidget* widgetParent = 0);
		virtual QString readInput() throw (Exception) = 0;
		virtual void print(QString s) = 0;
		virtual void printLine(QString s) = 0;
		virtual void draw(CADDrawing* drawing) = 0;
		virtual void updatePropertiesDisplay() = 0;
		virtual void quitApplication() = 0;
		
	protected:
		DrawingManager* drawingManager;
		CommandHistory* commandHistory;
		
	};
	
}

#endif // IO__IOINTERFACE_H
