/***************************************************************************
 *                                                                         *
 *   util/layerrenamingmanager.h                                           *
 *   (C) 2004 by Bernhard Jantscher                                        *
 *   ConstructCAD Project - Version 0.1                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef LAYERRENAMINGMANAGER_H
#define LAYERRENAMINGMANAGER_H

#include "layerrenaming.h"
#include <vector>
#include <qstring.h>

using namespace std;

namespace util
{
	typedef vector<LayerRenaming> RenamingVector;	
	
	class LayerRenamingManager {
		
		public:
			/** Constructor */
			LayerRenamingManager();
			/** Destructor */
			~LayerRenamingManager();
			
			/** @return the vector of renamings */
			RenamingVector getRenamings() const
			{ return renamings; }
			/** @return the renaming at given index */
			LayerRenaming getRenaming(int index) const
			{ return renamings.at(index); }
			/** @return the number of renamings */
			int getCount() const { return renamings.size(); }
			
			/**
			 * Add a layer renaming
			 * Call this function everytime a layer is renamed.
			 */
			void add(QString layerold, QString layernew);

			/** Debug function which shows the renamings */
			void showRenamings() {
				qDebug("------all renamings------"+QString::number(renamings.size()));				
				for (RenamingVector::iterator it = renamings.begin(); it != renamings.end(); it++)
				{
					qDebug(it->getOldLayer()+" - "+it->getNewLayer());
				}
				qDebug("end - ------all renamings------"+QString::number(renamings.size()));
			}
		
		protected:
			RenamingVector renamings;
			
	};
}

#endif // UTIL__LAYERRENAMINGMANAGER_H
